@@ -26,6 +26,7 @@
 #include <QFileInfo>
 #include <QDropEvent>
 #include <QMenu>
+#include <QSortFilterProxyModel>
 #include <QStyle>
 
 #include <KPushButton>
@@ -53,7 +54,6 @@
 #include "fieldlineedit.h"
 
 static const unsigned int interColumnSpace = 16;
-static const QStringList keyStart = QStringList() << Entry::ftUrl << QLatin1String("postscript") << Entry::ftLocalFile << Entry::ftDOI << Entry::ftFile << QLatin1String("ee") << QLatin1String("biburl");
 static const char *PropertyIdSuggestion = "PropertyIdSuggestion";
 
 ElementWidget::ElementWidget(QWidget *parent)
@@ -213,7 +213,7 @@ void EntryConfiguredWidget::createGUI()
         labeledFieldInput->isVerticallyMinimumExpaning = sfl.fieldInputLayout == KBibTeX::MultiLine || sfl.fieldInputLayout == KBibTeX::List || sfl.fieldInputLayout == KBibTeX::PersonList || sfl.fieldInputLayout == KBibTeX::KeywordList;
 
         /// create a label next to the editing widget
-        labeledFieldInput->label = new QLabel(QString("%1:").arg(sfl.uiLabel), this);
+        labeledFieldInput->label = new QLabel(QString(QLatin1String("%1:")).arg(sfl.uiLabel), this);
         labeledFieldInput->label->setBuddy(labeledFieldInput->fieldInput->buddy());
         /// align label's text vertically to match field input
         Qt::Alignment horizontalAlignment = (Qt::Alignment)(labeledFieldInput->label->style()->styleHint(QStyle::SH_FormLayoutLabelAlignment) & 0x001f);
@@ -372,15 +372,20 @@ bool ReferenceWidget::reset(QSharedPointer<const Element> element)
         buttonSuggestId->setEnabled(!isReadOnly);
         BibTeXEntries *be = BibTeXEntries::self();
         QString type = be->format(entry->type(), KBibTeX::cUpperCamelCase);
-        entryType->setCurrentIndex(-1);
-        entryType->lineEdit()->setText(type);
-        type = type.toLower();
-        int index = 0;
-        for (BibTeXEntries::ConstIterator it = be->constBegin(); it != be->constEnd(); ++it, ++index)
-            if (type == it->upperCamelCase.toLower() || type == it->upperCamelCaseAlt.toLower()) {
-                entryType->setCurrentIndex(index);
-                break;
-            }
+        int index = entryType->findData(type);
+        if (index == -1) {
+            const QString typeLower(type.toLower());
+            for (BibTeXEntries::ConstIterator it = be->constBegin(); it != be->constEnd(); ++it)
+                if (typeLower == it->upperCamelCaseAlt.toLower()) {
+                    index = entryType->findData(it->upperCamelCase);
+                    break;
+                }
+        }
+        entryType->setCurrentIndex(index);
+        if (index == -1) {
+             /// A customized value not known to KBibTeX
+             entryType->lineEdit()->setText(type);
+        }
 
         entryId->setText(entry->id());
         /// New entries have no values. Use this fact
@@ -467,6 +472,13 @@ void ReferenceWidget::createGUI()
     BibTeXEntries *be = BibTeXEntries::self();
     for (BibTeXEntries::ConstIterator it = be->constBegin(); it != be->constEnd(); ++it)
         entryType->addItem(it->label, it->upperCamelCase);
+    /// Sort the combo box locale-aware. Thus we need a SortFilterProxyModel
+    QSortFilterProxyModel *proxy = new QSortFilterProxyModel(entryType);
+    proxy->setSortLocaleAware(true);
+    proxy->setSourceModel(entryType->model());
+    entryType->model()->setParent(proxy);
+    entryType->setModel(proxy);
+    entryType->model()->sort(0);
 
     /// Button with a menu listing a set of preconfigured id suggestions
     buttonSuggestId = new KPushButton(KIcon("view-filter"), QLatin1String(""), this);
@@ -697,6 +709,8 @@ bool FilesWidget::canEdit(const Element *element)
     return typeid(*element) == typeid(Entry);
 }
 
+const QStringList FilesWidget::keyStart = QStringList() << Entry::ftUrl << QLatin1String("postscript") << Entry::ftLocalFile << Entry::ftDOI << Entry::ftFile << QLatin1String("ee") << QLatin1String("biburl");
+
 
 OtherFieldsWidget::OtherFieldsWidget(const QStringList &blacklistedFields, QWidget *parent)
         : ElementWidget(parent), blackListed(blacklistedFields)
