@@ -27,15 +27,13 @@
 #include <QMouseEvent>
 #include <QKeyEvent>
 #include <QSplitter>
-#include <QtCore/QPointer>
+#include <QPointer>
 
 #include <KPushButton>
 #include <KAction>
 #include <KDialog>
 #include <KActionCollection>
 #include <KLocale>
-#include <KXMLGUIClient>
-#include <KStandardDirs>
 #include <kparts/part.h>
 #include <KMessageBox>
 #include <KDebug>
@@ -53,8 +51,6 @@
 const int FieldNameRole = Qt::UserRole + 101;
 const int UserInputRole = Qt::UserRole + 103;
 
-const int maxFieldsCount = 1024;
-
 /**
  * Model to hold alternative values as visualized in the RadioTreeView
  */
@@ -162,7 +158,8 @@ public:
                     QFont f = p->font();
                     f.setItalic(true);
                     return f;
-                }
+                } else
+                    return p->font();
             }
         } else if (index.parent().parent() == QModelIndex()) {
             /// second-level entries for alternatives
@@ -641,9 +638,6 @@ FindDuplicatesUI::FindDuplicatesUI(KParts::Part *part, FileView *fileView)
     KAction *newAction = new KAction(KIcon("tab-duplicate"), i18n("Find Duplicates"), this);
     part->actionCollection()->addAction(QLatin1String("findduplicates"), newAction);
     connect(newAction, SIGNAL(triggered()), this, SLOT(slotFindDuplicates()));
-#if KDE_IS_VERSION(4, 4, 0)
-    part->replaceXMLFile(KStandardDirs::locate("data", "kbibtex/findduplicatesui.rc"), KStandardDirs::locateLocal("data", "kbibtex/findduplicatesui.rc"), true);
-#endif
 }
 
 FindDuplicatesUI::~FindDuplicatesUI()
