@@ -1,22 +1,21 @@
 /***************************************************************************
-*   Copyright (C) 2004-2012 by Thomas Fischer                             *
-*   fischer@unix-ag.uni-kl.de                                             *
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-*   This program is distributed in the hope that it will be useful,       *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
-*   GNU General Public License for more details.                          *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the                         *
-*   Free Software Foundation, Inc.,                                       *
-*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
-***************************************************************************/
+ *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ ***************************************************************************/
+
+#include "settingsfileexporterpdfpswidget.h"
 
 #include <QFormLayout>
 #include <QLineEdit>
@@ -26,8 +25,8 @@
 #include <KComboBox>
 #include <KLocale>
 
+#include "guihelper.h"
 #include "fileexportertoolchain.h"
-#include "settingsfileexporterpdfpswidget.h"
 
 class SettingsFileExporterPDFPSWidget::SettingsFileExporterPDFPSWidgetPrivate
 {
@@ -55,13 +54,16 @@ public:
     void loadState() {
         KConfigGroup configGroupGeneral(config, configGroupNameGeneral);
         const QString paperSizeName = configGroupGeneral.readEntry(FileExporter::keyPaperSize, FileExporter::defaultPaperSize);
-        p->selectValue(comboBoxPaperSize, paperSizeLabelToName.key(paperSizeName));
+        int row = GUIHelper::selectValue(comboBoxPaperSize->model(), paperSizeLabelToName.key(paperSizeName));
+        comboBoxPaperSize->setCurrentIndex(row);
 
         KConfigGroup configGroup(config, configGroupName);
         QString babelLanguage = configGroup.readEntry(FileExporterToolchain::keyBabelLanguage, FileExporterToolchain::defaultBabelLanguage);
-        p->selectValue(comboBoxBabelLanguage, babelLanguage);
+        row = GUIHelper::selectValue(comboBoxBabelLanguage->model(), babelLanguage);
+        comboBoxBabelLanguage->setCurrentIndex(row);
         QString bibliographyStyle = configGroup.readEntry(FileExporterToolchain::keyBibliographyStyle, FileExporterToolchain::defaultBibliographyStyle);
-        p->selectValue(comboBoxBibliographyStyle, bibliographyStyle);
+        row = GUIHelper::selectValue(comboBoxBibliographyStyle->model(), bibliographyStyle);
+        comboBoxBibliographyStyle->setCurrentIndex(row);
     }
 
     void saveState() {
@@ -76,9 +78,12 @@ public:
     }
 
     void resetToDefaults() {
-        p->selectValue(comboBoxPaperSize, paperSizeLabelToName[FileExporter::defaultPaperSize]);
-        p->selectValue(comboBoxBabelLanguage, FileExporterToolchain::defaultBabelLanguage);
-        p->selectValue(comboBoxBibliographyStyle, FileExporterToolchain::defaultBibliographyStyle);
+        int row = GUIHelper::selectValue(comboBoxPaperSize->model(), paperSizeLabelToName[FileExporter::defaultPaperSize]);
+        comboBoxPaperSize->setCurrentIndex(row);
+        row = GUIHelper::selectValue(comboBoxBabelLanguage->model(), FileExporterToolchain::defaultBabelLanguage);
+        comboBoxBabelLanguage->setCurrentIndex(row);
+        row = GUIHelper::selectValue(comboBoxBibliographyStyle->model(), FileExporterToolchain::defaultBibliographyStyle);
+        comboBoxBibliographyStyle->setCurrentIndex(row);
     }
 
     void setupGUI() {
