@@ -169,6 +169,10 @@ public:
     }
 };
 
+static bool sortStringsLocaleAware(const QString s1, const QString s2) {
+    return QString::localeAwareCompare(s1, s2) < 0;
+}
+
 FilterBar::FilterBar(QWidget *parent)
         : QWidget(parent), d(new FilterBarPrivate(this))
 {
@@ -201,9 +205,18 @@ FilterBar::FilterBar(QWidget *parent)
     d->comboBoxField->addItem(i18n("any field"), QVariant());
     d->comboBoxField->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
 
+    /// Use a map to get an alphabetically sorted list
+    QHash<QString, QString> fielddescs;
     foreach(const FieldDescription *fd, *BibTeXFields::self()) {
         if (fd->upperCamelCaseAlt.isEmpty())
-            d->comboBoxField->addItem(fd->label, fd->upperCamelCase);
+            fielddescs.insert(fd->label, fd->upperCamelCase);
+    }
+    /// Sort locale-aware
+    QList<QString> keys = fielddescs.keys();
+    qSort(keys.begin(), keys.end(), sortStringsLocaleAware);
+    foreach(const QString &key, keys) {
+        const QString &value = fielddescs[key];
+        d->comboBoxField->addItem(key, value);
     }
 
     d->buttonSearchPDFfiles = new KPushButton(this);
@@ -217,16 +230,6 @@ FilterBar::FilterBar(QWidget *parent)
     d->buttonClearAll->setToolTip(i18n("Reset filter criteria"));
     layout->addWidget(d->buttonClearAll, 0);
 
-    connect(d->comboBoxFilterText->lineEdit(), SIGNAL(textChanged(QString)), d->delayedTimer, SLOT(trigger()));
-    connect(d->comboBoxFilterText->lineEdit(), SIGNAL(returnPressed()), this, SLOT(userPressedEnter()));
-    connect(d->comboBoxCombination, SIGNAL(currentIndexChanged(int)), this, SLOT(comboboxStatusChanged()));
-    connect(d->comboBoxField, SIGNAL(currentIndexChanged(int)), this, SLOT(comboboxStatusChanged()));
-    connect(d->buttonSearchPDFfiles, SIGNAL(toggled(bool)), this, SLOT(comboboxStatusChanged()));
-    connect(d->comboBoxCombination, SIGNAL(currentIndexChanged(int)), d->delayedTimer, SLOT(trigger()));
-    connect(d->comboBoxField, SIGNAL(currentIndexChanged(int)), d->delayedTimer, SLOT(trigger()));
-    connect(d->buttonSearchPDFfiles, SIGNAL(toggled(bool)), d->delayedTimer, SLOT(trigger()));
-    connect(d->buttonClearAll, SIGNAL(clicked()), this, SLOT(resetState()));
-
     /// restore history on filter texts
     /// see addCompletionString for more detailed explanation
     KConfigGroup configGroup(d->config, d->configGroupName);
@@ -237,6 +240,16 @@ FilterBar::FilterBar(QWidget *parent)
     d->comboBoxCombination->setCurrentIndex(configGroup.readEntry("CurrentCombination", 0));
     d->comboBoxField->setCurrentIndex(configGroup.readEntry("CurrentField", 0));
 
+    connect(d->comboBoxFilterText->lineEdit(), SIGNAL(textChanged(QString)), d->delayedTimer, SLOT(trigger()));
+    connect(d->comboBoxFilterText->lineEdit(), SIGNAL(returnPressed()), this, SLOT(userPressedEnter()));
+    connect(d->comboBoxCombination, SIGNAL(currentIndexChanged(int)), this, SLOT(comboboxStatusChanged()));
+    connect(d->comboBoxField, SIGNAL(currentIndexChanged(int)), this, SLOT(comboboxStatusChanged()));
+    connect(d->buttonSearchPDFfiles, SIGNAL(toggled(bool)), this, SLOT(comboboxStatusChanged()));
+    connect(d->comboBoxCombination, SIGNAL(currentIndexChanged(int)), d->delayedTimer, SLOT(trigger()));
+    connect(d->comboBoxField, SIGNAL(currentIndexChanged(int)), d->delayedTimer, SLOT(trigger()));
+    connect(d->buttonSearchPDFfiles, SIGNAL(toggled(bool)), d->delayedTimer, SLOT(trigger()));
+    connect(d->buttonClearAll, SIGNAL(clicked()), this, SLOT(resetState()));
+
     d->restoreState();
 
     setFocusProxy(d->comboBoxFilterText);
