@@ -61,7 +61,7 @@ public:
     KBibTeX::Casing keywordCasing;
     Preferences::QuoteComment quoteComment;
     QString encoding, forcedEncoding;
-    bool protectCasing;
+    Qt::CheckState protectCasing;
     QString personNameFormatting;
     QString listSeparator;
     bool cancelFlag;
@@ -88,7 +88,7 @@ public:
         stringCloseDelimiter = stringDelimiter[1];
         keywordCasing = (KBibTeX::Casing)configGroup.readEntry(Preferences::keyKeywordCasing, (int)Preferences::defaultKeywordCasing);
         quoteComment = (Preferences::QuoteComment)configGroup.readEntry(Preferences::keyQuoteComment, (int)Preferences::defaultQuoteComment);
-        protectCasing = configGroup.readEntry(Preferences::keyProtectCasing, Preferences::defaultProtectCasing);
+        protectCasing = (Qt::CheckState)configGroup.readEntry(Preferences::keyProtectCasing, (int)Preferences::defaultProtectCasing);
         personNameFormatting = configGroup.readEntry(Preferences::keyPersonNameFormatting, QString());
         listSeparator = configGroup.readEntry(Preferences::keyListSeparator, Preferences::defaultListSeparator);
 
@@ -114,15 +114,12 @@ public:
             stringOpenDelimiter = stringDelimiter[0];
             stringCloseDelimiter = stringDelimiter[1];
         }
-        // FIXME due to bug in LaTeXEncoder, enforce {...} for now
-        stringOpenDelimiter = QLatin1Char('{');
-        stringCloseDelimiter = QLatin1Char('}');
         if (bibtexfile->hasProperty(File::QuoteComment))
             quoteComment = (Preferences::QuoteComment)bibtexfile->property(File::QuoteComment).toInt();
         if (bibtexfile->hasProperty(File::KeywordCasing))
             keywordCasing = (KBibTeX::Casing)bibtexfile->property(File::KeywordCasing).toInt();
         if (bibtexfile->hasProperty(File::ProtectCasing))
-            protectCasing = bibtexfile->property(File::ProtectCasing).toBool();
+            protectCasing = (Qt::CheckState)bibtexfile->property(File::ProtectCasing).toInt();
         if (bibtexfile->hasProperty(File::NameFormatting)) {
             /// if the user set "use global default", this property is an empty string
             /// in this case, keep default value
@@ -157,8 +154,13 @@ public:
             }
 
             // FIXME hack!
-            if (protectCasing && typeid(*value.first()) == typeid(PlainText) && (key == Entry::ftTitle || key == Entry::ftBookTitle || key == Entry::ftSeries))
-                addProtectiveCasing(text);
+            const QSharedPointer<ValueItem> first = *value.constBegin();
+            if (typeid(*first) == typeid(PlainText) && (key == Entry::ftTitle || key == Entry::ftBookTitle || key == Entry::ftSeries)) {
+                if (protectCasing == Qt::Checked)
+                    addProtectiveCasing(text);
+                else if (protectCasing == Qt::Unchecked)
+                    removeProtectiveCasing(text);
+            }
 
             iodevice->putChar(',');
             iodevice->putChar('\n');
@@ -181,8 +183,10 @@ public:
         BibTeXEntries *be = BibTeXEntries::self();
 
         QString text = p->internalValueToBibTeX(macro.value(), QString(), leUTF8);
-        if (protectCasing)
+        if (protectCasing == Qt::Checked)
             addProtectiveCasing(text);
+        else if (protectCasing == Qt::Unchecked)
+            removeProtectiveCasing(text);
 
         iodevice->putChar('@');
         iodevice->write(be->format(QLatin1String("String"), keywordCasing).toLatin1().data());
@@ -251,25 +255,64 @@ public:
         return true;
     }
 
-    void addProtectiveCasing(QString &text) {
-        if ((text[0] != '"' || text[text.length() - 1] != '"') && (text[0] != '{' || text[text.length() - 1] != '}')) {
-            /** nothing to protect, as this is no text string */
-            return;
+    QString addProtectiveCasing(QString &text) {
+        if (text.length() < 2 && (text[0] != QLatin1Char('"') || text[text.length() - 1] != QLatin1Char('"')) && (text[0] != QLatin1Char('{') || text[text.length() - 1] != QLatin1Char('}'))) {
+            /// Nothing to protect, as this is no text string
+            return text;
         }
 
         bool addBrackets = true;
 
-        if (text[1] == '{' && text[text.length() - 2] == '}') {
+        if (text[1] == QLatin1Char('{') && text[text.length() - 2] == QLatin1Char('}')) {
+            /// If the given text looks like this:  {{...}}
+            /// still check that it is not like this: {{..}..{..}}
             addBrackets = false;
             int count = 0;
-            for (int i = text.length() - 2; !addBrackets && i >= 1; --i)
-                if (text[i] == '{') ++count;
-                else if (text[i] == '}') --count;
-                else if (count == 0) addBrackets = true;
+            for (int i = text.length() - 2; !addBrackets && i > 1; --i) {
+                if (text[i] == QLatin1Char('{')) ++count;
+                else if (text[i] == QLatin1Char('}')) --count;
+                if (count == 0) addBrackets = true;
+            }
         }
 
         if (addBrackets)
-            text.insert(1, '{').insert(text.length(), '}');
+            text.insert(1, QLatin1String("{")).insert(text.length(),  QLatin1String("}"));
+
+        return text;
+    }
+
+    QString removeProtectiveCasing(QString &text) {
+        if (text.length() < 2 && (text[0] != QLatin1Char('"') || text[text.length() - 1] != QLatin1Char('"')) && (text[0] != QLatin1Char('{') || text[text.length() - 1] != QLatin1Char('}'))) {
+            /// Nothing to protect, as this is no text string
+            return text;
+        }
+
+        if (text[1] != QLatin1Char('{') || text[text.length() - 2] != QLatin1Char('}'))
+            /// Nothing to remove
+            return text;
+
+        bool removeBrackets = true;
+        int count = 0;
+        for (int i = text.length() - 2; removeBrackets && i > 1; --i) {
+            if (text[i] == QLatin1Char('{')) ++count;
+            else if (text[i] == QLatin1Char('}')) --count;
+            if (count == 0) removeBrackets = false;
+        }
+
+        if (removeBrackets)
+            text.remove(text.length() - 2, 1).remove(1, 1);
+
+        return text;
+    }
+
+    QString &protectQuotationMarks(QString &text) {
+        int p = -1;
+        while ((p = text.indexOf(QLatin1Char('"'), p + 1)) > 0)
+            if (p == 0 || text[p - 1] != QLatin1Char('\\')) {
+                text.insert(p + 1, QLatin1String("}")).insert(p, QLatin1String("{"));
+                ++p;
+            }
+        return text;
     }
 
     void applyEncoding(QString &encoding) {
@@ -478,15 +521,13 @@ QString FileExporterBibTeX::internalValueToBibTeX(const Value &value, const QStr
 
     EncoderLaTeX *encoder = useLaTeXEncoding == leLaTeX ? EncoderLaTeX::instance() : (useLaTeXEncoding == leUTF8 ? EncoderUTF8::instance() : NULL);
 
-    QString result = "";
+    QString result;
     bool isOpen = false;
-    /// variable to memorize which closing delimiter to use
-    QChar stringCloseDelimiter = d->stringCloseDelimiter;
     QSharedPointer<const ValueItem> prev;
     for (Value::ConstIterator it = value.constBegin(); it != value.constEnd(); ++it) {
         QSharedPointer<const MacroKey> macroKey = (*it).dynamicCast<const MacroKey>();
         if (!macroKey.isNull()) {
-            if (isOpen) result.append(stringCloseDelimiter);
+            if (isOpen) result.append(d->stringCloseDelimiter);
             isOpen = false;
             if (!result.isEmpty()) result.append(" # ");
             result.append(macroKey->text());
@@ -497,32 +538,19 @@ QString FileExporterBibTeX::internalValueToBibTeX(const Value &value, const QStr
                 QString textBody = encodercheck(encoder, plainText->text());
                 if (!isOpen) {
                     if (!result.isEmpty()) result.append(" # ");
-                    if (textBody.contains("\"")) {
-                        /// fall back to {...} delimiters if text contains quotation marks
-                        result.append(QLatin1Char('{'));
-                        stringCloseDelimiter = QLatin1Char('}');
-                    } else {
-                        result.append(d->stringOpenDelimiter);
-                        stringCloseDelimiter = d->stringCloseDelimiter;
-                    }
+                    result.append(d->stringOpenDelimiter);
                 } else if (!prev.dynamicCast<const PlainText>().isNull())
                     result.append(' ');
                 else if (!prev.dynamicCast<const Person>().isNull()) {
                     /// handle "et al." i.e. "and others"
                     result.append(" and ");
                 } else {
-                    result.append(stringCloseDelimiter).append(" # ");
-
-                    if (textBody.contains("\"")) {
-                        /// fall back to {...} delimiters if text contains quotation marks
-                        result.append("{");
-                        stringCloseDelimiter = QLatin1Char('}');
-                    } else {
-                        result.append(d->stringOpenDelimiter);
-                        stringCloseDelimiter = d->stringCloseDelimiter;
-                    }
+                    result.append(d->stringCloseDelimiter).append(" # ").append(d->stringOpenDelimiter);
                 }
                 isOpen = true;
+
+                if (d->stringOpenDelimiter == QLatin1Char('"'))
+                    d->protectQuotationMarks(textBody);
                 result.append(textBody);
                 prev = plainText;
             } else {
@@ -531,14 +559,7 @@ QString FileExporterBibTeX::internalValueToBibTeX(const Value &value, const QStr
                     QString textBody = verbatimText->text();
                     if (!isOpen) {
                         if (!result.isEmpty()) result.append(" # ");
-                        if (textBody.contains("\"")) {
-                            /// fall back to {...} delimiters if text contains quotation marks
-                            result.append("{");
-                            stringCloseDelimiter = QLatin1Char('}');
-                        } else {
-                            result.append(d->stringOpenDelimiter);
-                            stringCloseDelimiter = d->stringCloseDelimiter;
-                        }
+                        result.append(d->stringOpenDelimiter);
                     } else if (!prev.dynamicCast<const VerbatimText>().isNull()) {
                         if (key.toLower().startsWith(Entry::ftUrl) || key.toLower().startsWith(Entry::ftLocalFile) || key.toLower().startsWith(Entry::ftDOI))
                             /// Filenames and alike have be separated by a semicolon,
@@ -547,18 +568,12 @@ QString FileExporterBibTeX::internalValueToBibTeX(const Value &value, const QStr
                         else
                             result.append(' ');
                     } else {
-                        result.append(stringCloseDelimiter).append(" # ");
-
-                        if (textBody.contains("\"")) {
-                            /// fall back to {...} delimiters if text contains quotation marks
-                            result.append("{");
-                            stringCloseDelimiter = QLatin1Char('}');
-                        } else {
-                            result.append(d->stringOpenDelimiter);
-                            stringCloseDelimiter = d->stringCloseDelimiter;
-                        }
+                        result.append(d->stringCloseDelimiter).append(" # ").append(d->stringOpenDelimiter);
                     }
                     isOpen = true;
+
+                    if (d->stringOpenDelimiter == QLatin1Char('"'))
+                        d->protectQuotationMarks(textBody);
                     result.append(textBody);
                     prev = verbatimText;
                 } else {
@@ -582,30 +597,16 @@ QString FileExporterBibTeX::internalValueToBibTeX(const Value &value, const QStr
 
                         if (!isOpen) {
                             if (!result.isEmpty()) result.append(" # ");
-                            if (thisName.contains("\"")) {
-                                /// fall back to {...} delimiters if text contains quotation marks
-                                result.append("{");
-                                stringCloseDelimiter = QLatin1Char('}');
-                            } else {
-                                result.append(d->stringOpenDelimiter);
-                                stringCloseDelimiter = d->stringCloseDelimiter;
-                            }
+                            result.append(d->stringOpenDelimiter);
                         } else if (!prev.dynamicCast<const Person>().isNull())
                             result.append(" and ");
                         else {
-                            result.append(stringCloseDelimiter).append(" # ");
-
-                            if (thisName.contains("\"")) {
-                                /// fall back to {...} delimiters if text contains quotation marks
-                                result.append("{");
-                                stringCloseDelimiter = QLatin1Char('}');
-                            } else {
-                                result.append(d->stringOpenDelimiter);
-                                stringCloseDelimiter = d->stringCloseDelimiter;
-                            }
+                            result.append(d->stringCloseDelimiter).append(" # ").append(d->stringOpenDelimiter);
                         }
                         isOpen = true;
 
+                        if (d->stringOpenDelimiter == QLatin1Char('"'))
+                            d->protectQuotationMarks(thisName);
                         result.append(thisName);
                         prev = person;
                     } else {
@@ -614,30 +615,16 @@ QString FileExporterBibTeX::internalValueToBibTeX(const Value &value, const QStr
                             QString textBody = encodercheck(encoder, keyword->text());
                             if (!isOpen) {
                                 if (!result.isEmpty()) result.append(" # ");
-                                if (textBody.contains("\"")) {
-                                    /// fall back to {...} delimiters if text contains quotation marks
-                                    result.append("{");
-                                    stringCloseDelimiter = QLatin1Char('}');
-                                } else {
-                                    result.append(d->stringOpenDelimiter);
-                                    stringCloseDelimiter = d->stringCloseDelimiter;
-                                }
+                                result.append(d->stringOpenDelimiter);
                             } else if (!prev.dynamicCast<const Keyword>().isNull())
                                 result.append(d->listSeparator);
                             else {
-                                result.append(stringCloseDelimiter).append(" # ");
-
-                                if (textBody.contains("\"")) {
-                                    /// fall back to {...} delimiters if text contains quotation marks
-                                    result.append("{");
-                                    stringCloseDelimiter = QLatin1Char('}');
-                                } else {
-                                    result.append(d->stringOpenDelimiter);
-                                    stringCloseDelimiter = d->stringCloseDelimiter;
-                                }
+                                result.append(d->stringCloseDelimiter).append(" # ").append(d->stringOpenDelimiter);
                             }
                             isOpen = true;
 
+                            if (d->stringOpenDelimiter == QLatin1Char('"'))
+                                d->protectQuotationMarks(textBody);
                             result.append(textBody);
                             prev = keyword;
                         }
@@ -648,7 +635,7 @@ QString FileExporterBibTeX::internalValueToBibTeX(const Value &value, const QStr
         prev = *it;
     }
 
-    if (isOpen) result.append(stringCloseDelimiter);
+    if (isOpen) result.append(d->stringCloseDelimiter);
 
     return result;
 }
