@@ -40,8 +40,6 @@
 #include "bibtexfields.h"
 #include "fileexporterbibtex.h"
 
-const QString extraAlphaNumChars = QString("?'`-_:.+/$\\\"&");
-
 const char *FileImporterBibTeX::defaultCodecName = "utf-8";
 
 FileImporterBibTeX::FileImporterBibTeX(bool ignoreComments, KBibTeX::Casing keywordCasing)
@@ -60,7 +58,7 @@ File *FileImporterBibTeX::load(QIODevice *iodevice)
     m_cancelFlag = false;
 
     if (!iodevice->isReadable() && !iodevice->open(QIODevice::ReadOnly)) {
-        kDebug() << "Input device not readable";
+        kWarning() << "Input device not readable";
         return NULL;
     }
 
@@ -82,7 +80,7 @@ File *FileImporterBibTeX::load(QIODevice *iodevice)
     m_textStream->setCodec(defaultCodecName); ///< unless we learn something else, assume default codec
     result->setProperty(File::Encoding, QLatin1String("latex"));
 
-    QString rawText = "";
+    QString rawText;
     while (!m_textStream->atEnd()) {
         QString line = m_textStream->readLine();
         bool skipline = evaluateParameterComments(m_textStream, line.toLower(), result);
@@ -140,7 +138,8 @@ File *FileImporterBibTeX::load(QIODevice *iodevice)
         /// Set the file's preferences for name formatting
         result->setProperty(File::NameFormatting, m_statistics.countFirstNameFirst > m_statistics.countLastNameFirst ? Preferences::personNameFormatFirstLast : Preferences::personNameFormatLastFirst);
         /// Set the file's preferences for title protected
-        result->setProperty(File::ProtectCasing, m_statistics.countProtectedTitle > m_statistics.countUnprotectedTitle);
+        Qt::CheckState triState = (m_statistics.countProtectedTitle > m_statistics.countUnprotectedTitle * 4) ? Qt::Checked : ((m_statistics.countProtectedTitle * 4 < m_statistics.countUnprotectedTitle) ? Qt::Unchecked : Qt::PartiallyChecked);
+        result->setProperty(File::ProtectCasing, (int)triState);
         /// Set the file's preferences for quoting of comments
         if (m_statistics.countNoCommentQuote > m_statistics.countCommentCommand && m_statistics.countNoCommentQuote > m_statistics.countCommentPercent)
             result->setProperty(File::QuoteComment, (int)Preferences::qcNone);
@@ -176,12 +175,12 @@ Element *FileImporterBibTeX::nextElement()
     if (token == tAt) {
         QString elementType = readSimpleString();
 
-        if (elementType.toLower() == "comment") {
+        if (elementType.toLower() == QLatin1String("comment")) {
             ++m_statistics.countCommentCommand;
             return readCommentElement();
-        } else if (elementType.toLower() == "string")
+        } else if (elementType.toLower() == QLatin1String("string"))
             return readMacroElement();
-        else if (elementType.toLower() == "preamble")
+        else if (elementType.toLower() == QLatin1String("preamble"))
             return readPreambleElement();
         else if (elementType.toLower() == QLatin1String("import")) {
             kDebug() << "Skipping potential HTML/JavaScript @import statement";
@@ -197,7 +196,7 @@ Element *FileImporterBibTeX::nextElement()
         ++m_statistics.countCommentPercent;
         return readPlainCommentElement();
     } else if (token == tUnknown) {
-        kDebug() << "Unknown token '" << m_nextChar << "(" << QString("0x%1").arg(m_nextChar.unicode(), 4, 16, QLatin1Char('0')) << ")" << "' near line " << m_lineNo << "(" << m_prevLine << endl << m_currentLine << ")" << ", treating as comment";
+        kDebug() << "Unknown token '" << m_nextChar << "(" << QString(QLatin1String("0x%1")).arg(m_nextChar.unicode(), 4, 16, QLatin1Char('0')) << ")" << "' near line " << m_lineNo << "(" << m_prevLine << endl << m_currentLine << ")" << ", treating as comment";
         ++m_statistics.countNoCommentQuote;
         return readPlainCommentElement();
     }
@@ -365,9 +364,9 @@ Entry *FileImporterBibTeX::readEntryElement(const QString &typeString)
             if (m_nextChar.isLetter())
                 kWarning() << "Error in parsing entry" << id << "(near line" << m_lineNo << ":" << m_prevLine << endl << m_currentLine << "): Comma symbol (,) expected but got character" << m_nextChar << "(token" << tokenidToString(token) << ")";
             else if (m_nextChar.isPrint())
-                kWarning() << "Error in parsing entry" << id << "(near line" << m_lineNo << ":" << m_prevLine << endl << m_currentLine << "): Comma symbol (,) expected but got character" << m_nextChar << "(" << QString("0x%1").arg(m_nextChar.unicode(), 4, 16, QLatin1Char('0')) << ", token" << tokenidToString(token) << ")";
+                kWarning() << "Error in parsing entry" << id << "(near line" << m_lineNo << ":" << m_prevLine << endl << m_currentLine << "): Comma symbol (,) expected but got character" << m_nextChar << "(" << QString(QLatin1String("0x%1")).arg(m_nextChar.unicode(), 4, 16, QLatin1Char('0')) << ", token" << tokenidToString(token) << ")";
             else
-                kWarning() << "Error in parsing entry" << id << "(near line" << m_lineNo << ":" << m_prevLine << endl << m_currentLine << "): Comma symbol (,) expected but got character" << QString("0x%1").arg(m_nextChar.unicode(), 4, 16, QLatin1Char('0')) << "(token" << tokenidToString(token) << ")";
+                kWarning() << "Error in parsing entry" << id << "(near line" << m_lineNo << ":" << m_prevLine << endl << m_currentLine << "): Comma symbol (,) expected but got character" << QString(QLatin1String("0x%1")).arg(m_nextChar.unicode(), 4, 16, QLatin1Char('0')) << "(token" << tokenidToString(token) << ")";
             delete entry;
             return NULL;
         }
@@ -506,6 +505,8 @@ QString FileImporterBibTeX::readString(bool &isStringKey)
 
 QString FileImporterBibTeX::readSimpleString(const QChar &until)
 {
+    const QString extraAlphaNumChars = QLatin1String("?'`-_:.+/$\\\"&");
+
     QString result;
 
     if (!skipWhiteChar()) {
@@ -542,7 +543,7 @@ QString FileImporterBibTeX::readQuotedString()
     if (!readChar()) return QString();
 
     while (!m_nextChar.isNull()) {
-        if (m_nextChar == QLatin1Char('"') && m_prevChar != QLatin1Char('\\'))
+        if (m_nextChar == QLatin1Char('"') && m_prevChar != QLatin1Char('\\') && m_prevChar != QLatin1Char('{'))
             break;
         else
             result.append(m_nextChar);
@@ -551,6 +552,10 @@ QString FileImporterBibTeX::readQuotedString()
     }
 
     if (!readChar()) return QString();
+
+    /// Remove protection around quotation marks
+    result.replace(QLatin1String("{\"}"), QLatin1String("\""));
+
     return result;
 }
 
@@ -781,7 +786,7 @@ QList<QSharedPointer<Keyword> > FileImporterBibTeX::splitKeywords(const QString
     /// define a list of characters where keywords will be split along
     /// finalize list with null character
     static char splitChars[] = "\n;,\0";
-    static const QRegExp splitAlong[] = {QRegExp(QString("\\s*%1\\s*").arg(splitChars[0])), QRegExp(QString("\\s*%1\\s*").arg(splitChars[1])), QRegExp(QString("\\s*%1\\s*").arg(splitChars[2])), QRegExp()};
+    static const QRegExp splitAlong[] = {QRegExp(QString(QLatin1String("\\s*%1\\s*")).arg(splitChars[0])), QRegExp(QString(QLatin1String("\\s*%1\\s*")).arg(splitChars[1])), QRegExp(QString(QLatin1String("\\s*%1\\s*")).arg(splitChars[2])), QRegExp()};
     char *curSplitChar = splitChars;
     static const QRegExp unneccessarySpacing(QLatin1String("[ \n\r\t]+"));
     int index = 0;
@@ -836,13 +841,19 @@ QList<QSharedPointer<Person> > FileImporterBibTeX::splitNames(const QString &tex
     QString internalText = text;
 
     /// Remove invalid characters such as dots or (double) daggers for footnotes
-    static const QList<QChar> invalidChars = QList<QChar>() << QChar(0x00b7) << QChar(0x2020) << QChar(0x2217) << QChar(0x2021) << QChar('*');
+    static const QList<QChar> invalidChars = QList<QChar>() << QChar(0x00b7) << QChar(0x2020) << QChar(0x2217) << QChar(0x2021) << QChar('*') << QChar(0x21D1) /** Upwards double arrow */;
     for (QList<QChar>::ConstIterator it = invalidChars.constBegin(); it != invalidChars.constEnd(); ++it)
         /// Replacing daggers with commas ensures that they act as persons' names separator
         internalText = internalText.replace(*it, QChar(','));
     /// Remove numbers to footnotes
     static const QRegExp numberFootnoteRegExp(QLatin1String("(\\w)\\d+\\b"));
     internalText = internalText.replace(numberFootnoteRegExp, QLatin1String("\\1"));
+    /// Remove academic degrees
+    static const QRegExp academicDegreesRegExp(QLatin1String("(,\\s*)?(MA|PhD)\\b"));
+    internalText = internalText.remove(academicDegreesRegExp);
+    /// Remove email addresses
+    static const QRegExp emailAddressRegExp(QLatin1String("\\b[a-zA-Z0-9][a-zA-Z0-9._-]+[a-zA-Z0-9]@[a-z0-9][a-z0-9-]*([.][a-z0-9-]+)*([.][a-z]+)+\\b"));
+    internalText = internalText.remove(emailAddressRegExp);
 
     /// Split input string into tokens which are either name components (first or last name)
     /// or full names (composed of first and last name), depending on the input string's structure
@@ -1120,8 +1131,8 @@ bool FileImporterBibTeX::evaluateParameterComments(QTextStream *textStream, cons
     /** check if this file requests a special encoding */
     if (line.startsWith(QLatin1String("@comment{x-kbibtex-encoding=")) && line.endsWith(QLatin1Char('}'))) {
         QString encoding = line.mid(28, line.length() - 29);
-        textStream->setCodec(encoding == "latex" ? defaultCodecName : encoding.toLatin1().data());
-        file->setProperty(File::Encoding, encoding == "latex" ? encoding : textStream->codec()->name());
+        textStream->setCodec(encoding == QLatin1String("latex") ? defaultCodecName : encoding.toLatin1().data());
+        file->setProperty(File::Encoding, encoding == QLatin1String("latex") ? encoding : textStream->codec()->name());
         return true;
     } else if (line.startsWith(QLatin1String("@comment{x-kbibtex-personnameformatting=")) && line.endsWith(QLatin1Char('}'))) {
         // TODO usage of x-kbibtex-personnameformatting is deprecated,
@@ -1145,15 +1156,15 @@ bool FileImporterBibTeX::evaluateParameterComments(QTextStream *textStream, cons
 QString FileImporterBibTeX::tokenidToString(Token token)
 {
     switch (token) {
-    case tAt: return QString("At");
-    case tBracketClose: return QString("BracketClose");
-    case tBracketOpen: return QString("BracketOpen");
-    case tAlphaNumText: return QString("AlphaNumText");
-    case tAssign: return QString("Assign");
-    case tComma: return QString("Comma");
-    case tDoublecross: return QString("Doublecross");
-    case tEOF: return QString("EOF");
-    case tUnknown: return QString("Unknown");
-    default: return QString("<Unknown>");
+    case tAt: return QString(QLatin1String("At"));
+    case tBracketClose: return QString(QLatin1String("BracketClose"));
+    case tBracketOpen: return QString(QLatin1String("BracketOpen"));
+    case tAlphaNumText: return QString(QLatin1String("AlphaNumText"));
+    case tAssign: return QString(QLatin1String("Assign"));
+    case tComma: return QString(QLatin1String("Comma"));
+    case tDoublecross: return QString(QLatin1String("Doublecross"));
+    case tEOF: return QString(QLatin1String("EOF"));
+    case tUnknown: return QString(QLatin1String("Unknown"));
+    default: return QString(QLatin1String("<Unknown>"));
     }
 }
