@@ -26,7 +26,6 @@
 #include <KLocale>
 #include <KDebug>
 #include <kio/job.h>
-#include <KMessageBox>
 
 #include "file.h"
 #include "entry.h"
@@ -43,7 +42,7 @@ public:
     int numExpectedResults, numFoundResults;
     const QString acmPortalBaseUrl;
     int currentSearchPosition;
-    QStringList bibTeXUrls;
+    QStringList citationUrls;
 
     int curStep, numSteps;
 
@@ -65,11 +64,10 @@ public:
 
         /// ACM's BibTeX code does not properly use various commands.
         /// For example, ACM writes "Ke\ssler" instead of "Ke{\ss}ler"
-        static const QStringList inlineCommands = QStringList() << QLatin1String("ss");
+        static const QStringList inlineCommands = QStringList() << QLatin1String("\\ss");
         for (QStringList::ConstIterator it = inlineCommands.constBegin(); it != inlineCommands.constEnd(); ++it) {
-            const QString cmd = QString(QLatin1String("\\%1")).arg(*it);
-            const QString wrappedCmd = QString(QLatin1String("{%1}")).arg(cmd);
-            code = code.replace(cmd, wrappedCmd);
+            const QString wrappedCmd = QString(QLatin1String("{%1}")).arg(*it);
+            code = code.replace(*it, wrappedCmd);
         }
     }
 };
@@ -90,10 +88,10 @@ void OnlineSearchAcmPortal::startSearch(const QMap<QString, QString> &query, int
     m_hasBeenCanceled = false;
     d->joinedQueryString.clear();
     d->currentSearchPosition = 1;
-    d->bibTeXUrls.clear();
+    d->citationUrls.clear();
     d->numFoundResults = 0;
     d->curStep = 0;
-    d->numSteps = numResults + 2;
+    d->numSteps = numResults * 2 + 2;
 
     for (QMap<QString, QString>::ConstIterator it = query.constBegin(); it != query.constEnd(); ++it) {
         // FIXME: Is there a need for percent encoding?
@@ -146,23 +144,21 @@ void OnlineSearchAcmPortal::doneFetchingStartPage()
     QNetworkReply *reply = static_cast<QNetworkReply *>(sender());
 
     if (handleErrors(reply)) {
-        const QString htmlSource = QString::fromUtf8(reply->readAll().data());
+        const QString htmlSource = QString::fromUtf8(reply->readAll().constData());
         int p1 = -1, p2 = -1, p3 = -1;
-        if ((p1 = htmlSource.indexOf("<form name=\"qiksearch\"")) >= 0
-                && (p2 = htmlSource.indexOf("action=", p1)) >= 0
-                && (p3 = htmlSource.indexOf("\"", p2 + 8)) >= 0) {
-            QString action = decodeURL(htmlSource.mid(p2 + 8, p3 - p2 - 8));
-            KUrl url(d->acmPortalBaseUrl + action);
-            QString body = QString("Go=&query=%1").arg(d->joinedQueryString).simplified();
+        if ((p1 = htmlSource.indexOf(QLatin1String("<form name=\"qiksearch\""))) >= 0
+                && (p2 = htmlSource.indexOf(QLatin1String("action="), p1)) >= 0
+                && (p3 = htmlSource.indexOf(QLatin1String("\""), p2 + 8)) >= 0) {
+            const QString body = QString(QLatin1String("Go=&query=%1")).arg(d->joinedQueryString).simplified();
+            const QString action = decodeURL(htmlSource.mid(p2 + 8, p3 - p2 - 8));
+            QUrl url(reply->url().resolved(QUrl(action + QLatin1String("&") + body)));
 
             QNetworkRequest request(url);
-            request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
-            QNetworkReply *newReply = InternalNetworkAccessManager::self()->post(request, body.toUtf8());
+            QNetworkReply *newReply = InternalNetworkAccessManager::self()->get(request, reply);
             InternalNetworkAccessManager::self()->setNetworkReplyTimeout(newReply);
             connect(newReply, SIGNAL(finished()), this, SLOT(doneFetchingSearchPage()));
         } else {
             kWarning() << "Search using" << label() << "failed.";
-            KMessageBox::error(m_parent, i18n("Searching '%1' failed: Could not extract form from ACM's start page.", label()));
             emit stoppedSearch(resultUnspecifiedError);
         }
     } else
@@ -176,11 +172,13 @@ void OnlineSearchAcmPortal::doneFetchingSearchPage()
     QNetworkReply *reply = static_cast<QNetworkReply *>(sender());
 
     if (handleErrors(reply)) {
-        const QString htmlSource = QString::fromUtf8(reply->readAll().data());
-        static QRegExp paramRegExp("<a [^>]+\\?id=([0-9]+)\\.([0-9]+).*CFID=([0-9]+).*CFTOKEN=([0-9]+)", Qt::CaseInsensitive);
+        const QString htmlSource = QString::fromUtf8(reply->readAll().constData());
+
+        static const QRegExp citationUrlRegExp(QLatin1String("citation.cfm\\?id=[0-9][0-9.]+[0-9][^\">]+CFID=[0-9]+[^\">]+CFTOKEN=[0-9]+"), Qt::CaseInsensitive);
         int p1 = -1;
-        while ((p1 = htmlSource.indexOf(paramRegExp, p1 + 1)) >= 0) {
-            d->bibTeXUrls << d->acmPortalBaseUrl + QString("/downformats.cfm?id=%1&parent_id=%2&expformat=bibtex&CFID=%3&CFTOKEN=%4").arg(paramRegExp.cap(2)).arg(paramRegExp.cap(1)).arg(paramRegExp.cap(3)).arg(paramRegExp.cap(4));
+        while ((p1 = citationUrlRegExp.indexIn(htmlSource, p1 + 1)) >= 0) {
+            const QString newUrl = d->acmPortalBaseUrl + citationUrlRegExp.cap(0);
+            d->citationUrls << newUrl;
         }
 
         if (d->currentSearchPosition + 20 < d->numExpectedResults) {
@@ -193,18 +191,63 @@ void OnlineSearchAcmPortal::doneFetchingSearchPage()
             QNetworkReply *newReply = InternalNetworkAccessManager::self()->get(request, reply);
             InternalNetworkAccessManager::self()->setNetworkReplyTimeout(newReply);
             connect(newReply, SIGNAL(finished()), this, SLOT(doneFetchingSearchPage()));
-        } else if (!d->bibTeXUrls.isEmpty()) {
-            QNetworkRequest request(d->bibTeXUrls.first());
+        } else if (!d->citationUrls.isEmpty()) {
+            QNetworkRequest request(d->citationUrls.first());
             QNetworkReply *newReply = InternalNetworkAccessManager::self()->get(request, reply);
             InternalNetworkAccessManager::self()->setNetworkReplyTimeout(newReply);
-            connect(newReply, SIGNAL(finished()), this, SLOT(doneFetchingBibTeX()));
-            d->bibTeXUrls.removeFirst();
+            connect(newReply, SIGNAL(finished()), this, SLOT(doneFetchingCitation()));
+            d->citationUrls.removeFirst();
         } else {
             emit stoppedSearch(resultNoError);
             emit progress(d->numSteps, d->numSteps);
         }
+    }  else
+        kWarning() << "url was" << reply->url().toString();
+}
+
+void OnlineSearchAcmPortal::doneFetchingCitation()
+{
+    emit progress(++d->curStep, d->numSteps);
+
+    QNetworkReply *reply = static_cast<QNetworkReply *>(sender());
+    QString bibTeXUrl;
+
+    if (handleErrors(reply)) {
+        const QString htmlSource = QString::fromUtf8(reply->readAll().constData());
+
+        static const QRegExp parentIdRegExp(QLatin1String("parent_id=([0-9]+)"));
+        const int parentId = parentIdRegExp.indexIn(htmlSource) > 0 ? parentIdRegExp.cap(1).toInt() : 0;
+
+        static const QRegExp paramRegExp(QLatin1String("\\?id=([0-9][0-9.]+[0-9])[^\">]+CFID=([0-9]+)[^\">]+CFTOKEN=([0-9]+)"), Qt::CaseInsensitive);
+        int p1 = -1;
+        if (parentId > 0 && (p1 = paramRegExp.indexIn(htmlSource)) >= 0) {
+            bibTeXUrl = d->acmPortalBaseUrl + QString(QLatin1String("/downformats.cfm?id=%2&parent_id=%1&expformat=bibtex&CFID=%3&CFTOKEN=%4")).arg(QString::number(parentId), paramRegExp.cap(1),  paramRegExp.cap(2), paramRegExp.cap(3));
+        } else {
+            kWarning() << "No citation link found in " << reply->url().toString() << "  parentId=" << parentId;
+            emit stoppedSearch(resultNoError);
+            emit progress(d->numSteps, d->numSteps);
+            return;
+        }
     }  else
         kDebug() << "url was" << reply->url().toString();
+
+    if (bibTeXUrl.isEmpty()) {
+        if (!d->citationUrls.isEmpty()) {
+            QNetworkRequest request(d->citationUrls.first());
+            QNetworkReply *newReply = InternalNetworkAccessManager::self()->get(request, reply);
+            InternalNetworkAccessManager::self()->setNetworkReplyTimeout(newReply);
+            connect(newReply, SIGNAL(finished()), this, SLOT(doneFetchingCitation()));
+            d->citationUrls.removeFirst();
+        } else {
+            emit stoppedSearch(resultNoError);
+            emit progress(d->numSteps, d->numSteps);
+        }
+    } else {
+        QNetworkRequest request(bibTeXUrl);
+        QNetworkReply *newReply = InternalNetworkAccessManager::self()->get(request, reply);
+        InternalNetworkAccessManager::self()->setNetworkReplyTimeout(newReply);
+        connect(newReply, SIGNAL(finished()), this, SLOT(doneFetchingBibTeX()));
+    }
 }
 
 void OnlineSearchAcmPortal::doneFetchingBibTeX()
@@ -215,7 +258,7 @@ void OnlineSearchAcmPortal::doneFetchingBibTeX()
 
     if (handleErrors(reply)) {
         /// ensure proper treatment of UTF-8 characters
-        QString bibTeXcode = QString::fromUtf8(reply->readAll().data());
+        QString bibTeXcode = QString::fromUtf8(reply->readAll().constData());
 
         FileImporterBibTeX importer;
         d->sanitizeBibTeXCode(bibTeXcode);
@@ -230,12 +273,12 @@ void OnlineSearchAcmPortal::doneFetchingBibTeX()
             delete bibtexFile;
         }
 
-        if (!d->bibTeXUrls.isEmpty() && d->numFoundResults < d->numExpectedResults) {
-            QNetworkRequest request(d->bibTeXUrls.first());
+        if (!d->citationUrls.isEmpty() && d->numFoundResults < d->numExpectedResults) {
+            QNetworkRequest request(d->citationUrls.first());
             QNetworkReply *newReply = InternalNetworkAccessManager::self()->get(request, reply);
             InternalNetworkAccessManager::self()->setNetworkReplyTimeout(newReply);
-            connect(newReply, SIGNAL(finished()), this, SLOT(doneFetchingBibTeX()));
-            d->bibTeXUrls.removeFirst();
+            connect(newReply, SIGNAL(finished()), this, SLOT(doneFetchingCitation()));
+            d->citationUrls.removeFirst();
         } else {
             emit stoppedSearch(resultNoError);
             emit progress(d->numSteps, d->numSteps);
