@@ -133,7 +133,7 @@ void OnlineSearchDOI::startSearch()
     const KUrl url = d->buildQueryUrl();
     if (url.isValid()) {
         QNetworkRequest request(url);
-        request.setRawHeader(QString("Accept").toLatin1(), QString("text/bibliography; style=bibtex").toLatin1());
+        request.setRawHeader(QString(QLatin1String("Accept")).toLatin1(), QString(QLatin1String("text/bibliography; style=bibtex")).toLatin1());
         QNetworkReply *reply = InternalNetworkAccessManager::self()->get(request);
         InternalNetworkAccessManager::self()->setNetworkReplyTimeout(reply);
         connect(reply, SIGNAL(finished()), this, SLOT(downloadDone()));
@@ -154,7 +154,7 @@ void OnlineSearchDOI::startSearch(const QMap<QString, QString> &query, int numRe
     const KUrl url = d->buildQueryUrl(query, numResults);
     if (url.isValid()) {
         QNetworkRequest request(url);
-        request.setRawHeader(QString("Accept").toLatin1(), QString("text/bibliography; style=bibtex").toLatin1());
+        request.setRawHeader(QString(QLatin1String("Accept")).toLatin1(), QString(QLatin1String("text/bibliography; style=bibtex")).toLatin1());
         QNetworkReply *reply = InternalNetworkAccessManager::self()->get(request);
         InternalNetworkAccessManager::self()->setNetworkReplyTimeout(reply);
         connect(reply, SIGNAL(finished()), this, SLOT(downloadDone()));
@@ -203,12 +203,12 @@ void OnlineSearchDOI::downloadDone()
             ++d->numSteps;
 
             QNetworkRequest request(redirUrl);
-            request.setRawHeader(QString("Accept").toLatin1(), QString("text/bibliography; style=bibtex").toLatin1());
+            request.setRawHeader(QString(QLatin1String("Accept")).toLatin1(), QString(QLatin1String("text/bibliography; style=bibtex")).toLatin1());
             QNetworkReply *newReply = InternalNetworkAccessManager::self()->get(request);
             InternalNetworkAccessManager::self()->setNetworkReplyTimeout(newReply);
             connect(newReply, SIGNAL(finished()), this, SLOT(downloadDone()));
         } else {  /// ensure proper treatment of UTF-8 characters
-            const QString bibTeXcode = QString::fromUtf8(reply->readAll().data());
+            const QString bibTeXcode = QString::fromUtf8(reply->readAll().constData());
 
             if (!bibTeXcode.isEmpty()) {
                 FileImporterBibTeX importer;
