@@ -196,7 +196,7 @@ void OnlineSearchGoogleScholar::doneFetchingConfigPage()
     QNetworkReply *reply = static_cast<QNetworkReply *>(sender());
 
     if (handleErrors(reply)) {
-        const QString htmlText = QString::fromUtf8(reply->readAll().data());
+        const QString htmlText = QString::fromUtf8(reply->readAll().constData());
         QMap<QString, QString> inputMap = formParameters(htmlText, "<form ");
         inputMap[QLatin1String("hl")] = QLatin1String("en");
         inputMap[QLatin1String("scis")] = QLatin1String("yes");
@@ -224,11 +224,11 @@ void OnlineSearchGoogleScholar::doneFetchingSetConfigPage()
 
     if (handleErrors(reply)) {
         KUrl url(QString(d->queryPageUrl).arg(reply->url().host()));
-        url.addEncodedQueryItem(QString("as_q").toLatin1(), d->queryFreetext.toLatin1());
-        url.addEncodedQueryItem(QString("as_sauthors").toLatin1(), d->queryAuthor.toLatin1());
-        url.addEncodedQueryItem(QString("as_ylo").toLatin1(), d->queryYear.toLatin1());
-        url.addEncodedQueryItem(QString("as_yhi").toLatin1(), d->queryYear.toLatin1());
-        url.addEncodedQueryItem(QString("as_vis").toLatin1(), "1"); ///< include citations
+        url.addEncodedQueryItem(QString(QLatin1String("as_q")).toLatin1(), d->queryFreetext.toLatin1());
+        url.addEncodedQueryItem(QString(QLatin1String("as_sauthors")).toLatin1(), d->queryAuthor.toLatin1());
+        url.addEncodedQueryItem(QString(QLatin1String("as_ylo")).toLatin1(), d->queryYear.toLatin1());
+        url.addEncodedQueryItem(QString(QLatin1String("as_yhi")).toLatin1(), d->queryYear.toLatin1());
+        url.addEncodedQueryItem(QString(QLatin1String("as_vis")).toLatin1(), "1"); ///< include citations
         url.addQueryItem("num", QString::number(d->numResults));
         url.addQueryItem("btnG", "Search Scholar");
 
@@ -247,7 +247,7 @@ void OnlineSearchGoogleScholar::doneFetchingQueryPage()
     QNetworkReply *reply = static_cast<QNetworkReply *>(sender());
 
     if (handleErrors(reply)) {
-        const QString htmlText = QString::fromUtf8(reply->readAll().data());
+        const QString htmlText = QString::fromUtf8(reply->readAll().constData());
 
         static const QRegExp linkToBib("/scholar.bib\\?[^\" >]+");
         int pos = 0;
@@ -298,66 +298,76 @@ void OnlineSearchGoogleScholar::doneFetchingBibTeX()
     const QString primaryUrl = reply->property("primaryurl").toString();
     const QString documentUrl = reply->property("documenturl").toString();
 
-    if (handleErrors(reply)) {
-        /// ensure proper treatment of UTF-8 characters
-        QString rawText = QString::fromUtf8(reply->readAll().data());
-        File *bibtexFile = d->importer.fromString(rawText);
-
-        bool hasEntry = false;
-        if (bibtexFile != NULL) {
-            for (File::ConstIterator it = bibtexFile->constBegin(); it != bibtexFile->constEnd(); ++it) {
-                QSharedPointer<Entry> entry = (*it).dynamicCast<Entry>();
-                if (!entry.isNull()) {
-                    Value v;
-                    v.append(QSharedPointer<VerbatimText>(new VerbatimText(label())));
-                    entry->insert("x-fetchedfrom", v);
-                    if (!primaryUrl.isEmpty()) {
-                        /// There is an external document associated with this BibTeX entry
-                        Value urlValue = entry->value(Entry::ftUrl);
-                        urlValue.append(QSharedPointer<VerbatimText>(new VerbatimText(primaryUrl)));
-                        entry->insert(Entry::ftUrl, urlValue);
-                    }
-                    if (!documentUrl.isEmpty() &&
-                            primaryUrl != documentUrl /** avoid duplicates */) {
-                        /// There is a web page associated with this BibTeX entry
-                        Value urlValue = entry->value(Entry::ftUrl);
-                        urlValue.append(QSharedPointer<VerbatimText>(new VerbatimText(documentUrl)));
-                        entry->insert(Entry::ftUrl, urlValue);
-                    }
-                    emit foundEntry(entry);
-                    hasEntry = true;
-                }
-            }
-            delete bibtexFile;
-        }
-
-        if (!hasEntry) {
-            kWarning() << "Searching" << label() << "resulted in invalid BibTeX data:" << rawText;
-            emit stoppedSearch(resultUnspecifiedError);
-            return;
-        }
-
-        if (!d->listBibTeXurls.isEmpty()) {
-            const QString bibtexUrl = d->listBibTeXurls.constBegin().key();
-            const QStringList urls = d->listBibTeXurls.constBegin().value().split(QLatin1String("|"), QString::KeepEmptyParts);
-            const QString primaryUrl = urls.first();
-            const QString documentUrl = urls.last();
-            QNetworkRequest request(bibtexUrl);
-            QNetworkReply *newReply = InternalNetworkAccessManager::self()->get(request, reply);
-            InternalNetworkAccessManager::self()->setNetworkReplyTimeout(newReply);
-            if (!primaryUrl.isEmpty()) {
-                /// Store primary URL as a property of the request/reply
-                newReply->setProperty("primaryurl", QVariant::fromValue<QString>(primaryUrl));
-            }
-            if (!documentUrl.isEmpty()) {
-                /// Store URL to document as a property of the request/reply
-                newReply->setProperty("documenturl", QVariant::fromValue<QString>(documentUrl));
-            }
-            connect(newReply, SIGNAL(finished()), this, SLOT(doneFetchingBibTeX()));
-            d->listBibTeXurls.erase(d->listBibTeXurls.begin());
+    KUrl newDomainUrl;
+    if (handleErrors(reply, newDomainUrl)) {
+        if (newDomainUrl.isValid() && newDomainUrl != reply->url()) {
+            /// following redirection to country-specific domain
+            ++d->numSteps;
+            QNetworkRequest request(newDomainUrl);
+            QNetworkReply *reply = InternalNetworkAccessManager::self()->get(request);
+            InternalNetworkAccessManager::self()->setNetworkReplyTimeout(reply);
+            connect(reply, SIGNAL(finished()), this, SLOT(doneFetchingBibTeX()));
         } else {
-            emit stoppedSearch(resultNoError);
-            emit progress(d->numSteps, d->numSteps);
+            /// ensure proper treatment of UTF-8 characters
+            QString rawText = QString::fromUtf8(reply->readAll().constData());
+            File *bibtexFile = d->importer.fromString(rawText);
+
+            bool hasEntry = false;
+            if (bibtexFile != NULL) {
+                for (File::ConstIterator it = bibtexFile->constBegin(); it != bibtexFile->constEnd(); ++it) {
+                    QSharedPointer<Entry> entry = (*it).dynamicCast<Entry>();
+                    if (!entry.isNull()) {
+                        Value v;
+                        v.append(QSharedPointer<VerbatimText>(new VerbatimText(label())));
+                        entry->insert("x-fetchedfrom", v);
+                        if (!primaryUrl.isEmpty()) {
+                            /// There is an external document associated with this BibTeX entry
+                            Value urlValue = entry->value(Entry::ftUrl);
+                            urlValue.append(QSharedPointer<VerbatimText>(new VerbatimText(primaryUrl)));
+                            entry->insert(Entry::ftUrl, urlValue);
+                        }
+                        if (!documentUrl.isEmpty() &&
+                                primaryUrl != documentUrl /** avoid duplicates */) {
+                            /// There is a web page associated with this BibTeX entry
+                            Value urlValue = entry->value(Entry::ftUrl);
+                            urlValue.append(QSharedPointer<VerbatimText>(new VerbatimText(documentUrl)));
+                            entry->insert(Entry::ftUrl, urlValue);
+                        }
+                        emit foundEntry(entry);
+                        hasEntry = true;
+                    }
+                }
+                delete bibtexFile;
+            }
+
+            if (!hasEntry) {
+                kWarning() << "Searching" << label() << "resulted in invalid BibTeX data:" << rawText;
+                emit stoppedSearch(resultUnspecifiedError);
+                return;
+            }
+
+            if (!d->listBibTeXurls.isEmpty()) {
+                const QString bibtexUrl = d->listBibTeXurls.constBegin().key();
+                const QStringList urls = d->listBibTeXurls.constBegin().value().split(QLatin1String("|"), QString::KeepEmptyParts);
+                const QString primaryUrl = urls.first();
+                const QString documentUrl = urls.last();
+                QNetworkRequest request(bibtexUrl);
+                QNetworkReply *newReply = InternalNetworkAccessManager::self()->get(request, reply);
+                InternalNetworkAccessManager::self()->setNetworkReplyTimeout(newReply);
+                if (!primaryUrl.isEmpty()) {
+                    /// Store primary URL as a property of the request/reply
+                    newReply->setProperty("primaryurl", QVariant::fromValue<QString>(primaryUrl));
+                }
+                if (!documentUrl.isEmpty()) {
+                    /// Store URL to document as a property of the request/reply
+                    newReply->setProperty("documenturl", QVariant::fromValue<QString>(documentUrl));
+                }
+                connect(newReply, SIGNAL(finished()), this, SLOT(doneFetchingBibTeX()));
+                d->listBibTeXurls.erase(d->listBibTeXurls.begin());
+            } else {
+                emit stoppedSearch(resultNoError);
+                emit progress(d->numSteps, d->numSteps);
+            }
         }
     } else
         kDebug() << "url was" << reply->url().toString();
