@@ -147,7 +147,7 @@ void OnlineSearchIEEEXplore::doneFetchingXML()
             connect(reply, SIGNAL(finished()), this, SLOT(doneFetchingXML()));
         } else {
             /// ensure proper treatment of UTF-8 characters
-            const QString xmlCode = QString::fromUtf8(reply->readAll().data());
+            const QString xmlCode = QString::fromUtf8(reply->readAll().constData());
 
             /// use XSL transformation to get BibTeX document from XML result
             const QString bibTeXcode = d->xslt->transform(xmlCode);
