@@ -33,7 +33,7 @@ private:
     // UNUSED OnlineSearchJStor *p;
 
 public:
-    int numFoundResults, curStep, numSteps;
+    int numExpectedResults, curStep, numSteps;
     static const QString jstorBaseUrl;
     KUrl queryUrl;
 
@@ -62,7 +62,7 @@ void OnlineSearchJStor::startSearch(const QMap<QString, QString> &query, int num
     m_hasBeenCanceled = false;
     d->curStep = 0;
     d->numSteps = 3;
-    d->numFoundResults = 0;
+    d->numExpectedResults = numResults;
 
     /// Build search URL, to be used in the second step
     /// after fetching the start page
@@ -72,28 +72,27 @@ void OnlineSearchJStor::startSearch(const QMap<QString, QString> &query, int num
     d->queryUrl.addQueryItem("wc", "on"); /// include external references, too
     d->queryUrl.addQueryItem("la", ""); /// no specific language
     d->queryUrl.addQueryItem("jo", ""); /// no specific journal
-    d->queryUrl.addQueryItem("Search", "Search");
     d->queryUrl.addQueryItem("hp", QString::number(numResults)); /// hits per page
     int queryNumber = 0;
     QStringList elements = splitRespectingQuotationMarks(query[queryKeyTitle]);
     foreach(const QString &element, elements) {
-        if (queryNumber > 0) d->queryUrl.addQueryItem(QString("c%1").arg(queryNumber), "AND"); ///< join search terms with an AND operation
-        d->queryUrl.addQueryItem(QString("f%1").arg(queryNumber), "ti");
-        d->queryUrl.addQueryItem(QString("q%1").arg(queryNumber), element);
+        if (queryNumber > 0) d->queryUrl.addQueryItem(QString(QLatin1String("c%1")).arg(queryNumber), "AND"); ///< join search terms with an AND operation
+        d->queryUrl.addQueryItem(QString(QLatin1String("f%1")).arg(queryNumber), "ti");
+        d->queryUrl.addQueryItem(QString(QLatin1String("q%1")).arg(queryNumber), element);
         ++queryNumber;
     }
     elements = splitRespectingQuotationMarks(query[queryKeyAuthor]);
     foreach(const QString &element, elements) {
-        if (queryNumber > 0) d->queryUrl.addQueryItem(QString("c%1").arg(queryNumber), "AND"); ///< join search terms with an AND operation
-        d->queryUrl.addQueryItem(QString("f%1").arg(queryNumber), "au");
-        d->queryUrl.addQueryItem(QString("q%1").arg(queryNumber), element);
+        if (queryNumber > 0) d->queryUrl.addQueryItem(QString(QLatin1String("c%1")).arg(queryNumber), "AND"); ///< join search terms with an AND operation
+        d->queryUrl.addQueryItem(QString(QLatin1String("f%1")).arg(queryNumber), "au");
+        d->queryUrl.addQueryItem(QString(QLatin1String("q%1")).arg(queryNumber), element);
         ++queryNumber;
     }
     elements = splitRespectingQuotationMarks(query[queryKeyFreeText]);
     foreach(const QString &element, elements) {
-        if (queryNumber > 0) d->queryUrl.addQueryItem(QString("c%1").arg(queryNumber), "AND"); ///< join search terms with an AND operation
-        d->queryUrl.addQueryItem(QString("f%1").arg(queryNumber), "all");
-        d->queryUrl.addQueryItem(QString("q%1").arg(queryNumber), element);
+        if (queryNumber > 0) d->queryUrl.addQueryItem(QString(QLatin1String("c%1")).arg(queryNumber), "AND"); ///< join search terms with an AND operation
+        d->queryUrl.addQueryItem(QString(QLatin1String("f%1")).arg(queryNumber), "all");
+        d->queryUrl.addQueryItem(QString(QLatin1String("q%1")).arg(queryNumber), element);
         ++queryNumber;
     }
     if (!query[queryKeyYear].isEmpty()) {
@@ -121,7 +120,7 @@ QString OnlineSearchJStor::label() const
 
 QString OnlineSearchJStor::favIconUrl() const
 {
-    return QLatin1String("http://www.jstor.org/templates/jsp/favicon.ico");
+    return QLatin1String("http://www.jstor.org/assets/search_20151218T0921/files/search/images/favicon.ico");
 }
 
 OnlineSearchQueryFormAbstract *OnlineSearchJStor::customWidget(QWidget *)
@@ -173,32 +172,37 @@ void OnlineSearchJStor::doneFetchingResultPage()
 
     if (handleErrors(reply)) {
         /// ensure proper treatment of UTF-8 characters
-        QString htmlText = QString::fromUtf8(reply->readAll().data());
+        QString htmlText = QString::fromUtf8(reply->readAll().constData());
 
         /// extract all unique DOI from HTML code
-        QSet<QString> uniqueDOIs;
-        int p = -1;
-        while ((p = KBibTeX::doiRegExp.indexIn(htmlText, p + 1)) >= 0)
-            uniqueDOIs.insert(KBibTeX::doiRegExp.cap(0));
+        QStringList uniqueDOIs;
+        int p = -6;
+        while ((p = KBibTeX::doiRegExp.indexIn(htmlText, p + 6)) >= 0) {
+            QString doi = KBibTeX::doiRegExp.cap(0);
+            // FIXME DOI RegExp accepts DOIs with question marks, causes problems here
+            const int p = doi.indexOf(QLatin1Char('?'));
+            if (p > 0) doi = doi.left(p);
+            if (!uniqueDOIs.contains(doi))
+                uniqueDOIs.append(doi);
+        }
 
         if (uniqueDOIs.isEmpty()) {
-            /// no results found
+            /// No results found
             emit progress(d->numSteps, d->numSteps);
             emit stoppedSearch(resultNoError);
         } else {
-            /// Build search URL, to be used in the second step
-            /// after fetching the start page
-            KUrl bibTeXUrl = KUrl(d->jstorBaseUrl);
-            bibTeXUrl.setPath("/action/downloadCitation");
-            bibTeXUrl.addQueryItem("userAction", "export");
-            bibTeXUrl.addQueryItem("format", "bibtex"); /// request BibTeX format
-            bibTeXUrl.addQueryItem("include", "abs"); /// include abstracts
-            foreach(const QString &doi, uniqueDOIs) {
-                bibTeXUrl.addQueryItem("doi", doi);
+            /// Build POST request that should return a BibTeX document
+            QString body;
+            int numResults = 0;
+            for (QStringList::ConstIterator it = uniqueDOIs.constBegin(); numResults < d->numExpectedResults && it != uniqueDOIs.constEnd(); ++it, ++numResults) {
+                if (!body.isEmpty()) body.append(QLatin1String("&"));
+                body.append(QLatin1String("citations=") + encodeURL(*it));
             }
-
+            KUrl bibTeXUrl = KUrl(d->jstorBaseUrl);
+            bibTeXUrl.setPath("/citation/bulk/text");
             QNetworkRequest request(bibTeXUrl);
-            QNetworkReply *newReply = InternalNetworkAccessManager::self()->get(request);
+            request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
+            QNetworkReply *newReply = InternalNetworkAccessManager::self()->post(request, body.toUtf8());
             InternalNetworkAccessManager::self()->setNetworkReplyTimeout(newReply);
             connect(newReply, SIGNAL(finished()), this, SLOT(doneFetchingBibTeXCode()));
         }
@@ -214,23 +218,23 @@ void OnlineSearchJStor::doneFetchingBibTeXCode()
 
     if (handleErrors(reply)) {
         /// ensure proper treatment of UTF-8 characters
-        const QString bibTeXcode = QString::fromUtf8(reply->readAll().data());
+        const QString bibTeXcode = QString::fromUtf8(reply->readAll().constData());
 
         FileImporterBibTeX importer;
         File *bibtexFile = importer.fromString(bibTeXcode);
-
+        int numFoundResults = 0;
         if (bibtexFile != NULL) {
             for (File::ConstIterator it = bibtexFile->constBegin(); it != bibtexFile->constEnd(); ++it) {
                 QSharedPointer<Entry> entry = (*it).dynamicCast<Entry>();
                 if (publishEntry(entry))
-                    ++d->numFoundResults;
+                    ++numFoundResults;
 
             }
             delete bibtexFile;
         }
 
         emit progress(d->numSteps, d->numSteps);
-        emit stoppedSearch(d->numFoundResults > 0 ? resultNoError : resultUnspecifiedError);
+        emit stoppedSearch(numFoundResults > 0 ? resultNoError : resultUnspecifiedError);
     } else
         kDebug() << "url was" << reply->url().toString();
 }
@@ -256,7 +260,7 @@ void OnlineSearchJStor::sanitizeEntry(QSharedPointer<Entry> entry)
         entry->insert(QLatin1String("jstor_id"), v);
     }
 
-    const QString formattedDateKey = "jstor_formatteddate";
+    const QString formattedDateKey = QLatin1String("jstor_formatteddate");
     const QString formattedDate = PlainTextValue::text(entry->value(formattedDateKey));
 
     /// first, try to guess month by inspecting the beginning
