@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -32,16 +32,16 @@
 
 using namespace Zotero;
 
-const QString top = QLatin1String("top");
-
 class Zotero::Collection::Private
 {
 private:
     Zotero::Collection *p;
-    Zotero::API *api;
+    QSharedPointer<Zotero::API> api;
 
 public:
-    Private(API *a, Zotero::Collection *parent)
+    static const QString top;
+
+    Private(QSharedPointer<Zotero::API> a, Zotero::Collection *parent)
             : p(parent), api(a) {
         initialized = false;
         busy = false;
@@ -58,6 +58,7 @@ public:
     QNetworkReply *requestZoteroUrl(const KUrl &url) {
         busy = true;
         KUrl internalUrl = url;
+        api->addKeyToUrl(internalUrl);
         api->addLimitToUrl(internalUrl);
         QNetworkRequest request = api->request(internalUrl);
         QNetworkReply *reply = InternalNetworkAccessManager::self()->get(request);
@@ -79,10 +80,12 @@ public:
     }
 };
 
-Collection::Collection(API *api, QObject *parent)
+const QString Zotero::Collection::Private::top = QLatin1String("top");
+
+Collection::Collection(QSharedPointer<Zotero::API> api, QObject *parent)
         : QObject(parent), d(new Zotero::Collection::Private(api, this))
 {
-    d->collectionToLabel[top] = i18n("Library");
+    d->collectionToLabel[Private::top] = i18n("Library");
 
     KUrl url = api->baseUrl();
     url.addPath(QLatin1String("/collections/top"));
@@ -124,7 +127,7 @@ uint Collection::collectionNumericId(const QString &collectionId) const
 {
     if (!d->initialized) return 0;
 
-    if (collectionId == top) /// root node
+    if (collectionId == Private::top) /// root node
         return 0;
 
     return qHash(collectionId);
@@ -133,7 +136,7 @@ uint Collection::collectionNumericId(const QString &collectionId) const
 QString Collection::collectionFromNumericId(uint numericId) const
 {
     if (numericId == 0) /// root node
-        return top;
+        return Private::top;
 
     // TODO make those resolutions more efficient
     const QList<QString> keys = d->collectionToLabel.keys();
@@ -147,7 +150,7 @@ QString Collection::collectionFromNumericId(uint numericId) const
 void Collection::finishedFetchingCollection()
 {
     QNetworkReply *reply = static_cast<QNetworkReply *>(sender());
-    QString parentId = top;
+    QString parentId = Private::top;
 
     if (reply->error() == QNetworkReply::NoError) {
         QString nextPage;
@@ -158,7 +161,7 @@ void Collection::finishedFetchingCollection()
                 /// Not perfect: guess author name from collection's title
                 const QStringList titleFragments = xmlReader.readElementText(QXmlStreamReader::IncludeChildElements).split(QLatin1String(" / "));
                 if (titleFragments.count() == 3)
-                    d->collectionToLabel[top] = i18n("%1's Library", titleFragments[1]);
+                    d->collectionToLabel[Private::top] = i18n("%1's Library", titleFragments[1]);
             } else if (tt == QXmlStreamReader::StartElement && xmlReader.name() == QLatin1String("entry")) {
                 QString title, key;
                 while (!xmlReader.atEnd() && !xmlReader.hasError()) {
