@@ -26,7 +26,7 @@
 #include <QLayout>
 #include <QKeyEvent>
 #include <QSignalMapper>
-#include <QtCore/QPointer>
+#include <QPointer>
 #include <QFileSystemWatcher>
 
 #include <KFileDialog>
@@ -109,10 +109,16 @@ public:
     KAction *colorLabelContextMenuAction;
     QFileSystemWatcher fileSystemWatcher;
 
-    KBibTeXPartPrivate(KBibTeXPart *parent)
+    KBibTeXPartPrivate(QWidget *parentWidget, KBibTeXPart *parent)
             : p(parent), config(KSharedConfig::openConfig(QLatin1String("kbibtexrc"))), bibTeXFile(NULL), model(NULL), sortFilterProxyModel(NULL), signalMapperNewElement(new QSignalMapper(parent)), viewDocumentMenu(new KMenu(i18n("View Document"), parent->widget())), signalMapperViewDocument(new QSignalMapper(parent)), isSaveAsOperation(false), fileSystemWatcher(p) {
         connect(signalMapperViewDocument, SIGNAL(mapped(QObject*)), p, SLOT(elementViewDocumentMenu(QObject*)));
         connect(&fileSystemWatcher, SIGNAL(fileChanged(QString)), p, SLOT(fileExternallyChange(QString)));
+
+        partWidget = new PartWidget(parentWidget);
+        partWidget->fileView()->setReadOnly(!p->isReadWrite());
+        connect(partWidget->fileView(), SIGNAL(modified()), p, SLOT(setModified()));
+
+        setupActions();
     }
 
     ~KBibTeXPartPrivate() {
@@ -123,16 +129,129 @@ public:
         delete signalMapperViewDocument;
     }
 
+    void setupActions()
+    {
+        /// "Save" action
+        fileSaveAction = p->actionCollection()->addAction(KStandardAction::Save, p, SLOT(documentSave()));
+        fileSaveAction->setEnabled(false);
+        p->actionCollection()->addAction(KStandardAction::SaveAs, p, SLOT(documentSaveAs()));
+        /// "Save copy as" action
+        KAction *saveCopyAsAction = new KAction(KIcon("document-save"), i18n("Save Copy As..."), p);
+        p->actionCollection()->addAction("file_save_copy_as", saveCopyAsAction);
+        connect(saveCopyAsAction, SIGNAL(triggered(bool)), p, SLOT(documentSaveCopyAs()));
+
+        /// Filter bar widget
+        KAction *filterWidgetAction = new KAction(i18n("Filter"), p);
+        p->actionCollection()->addAction("toolbar_filter_widget", filterWidgetAction);
+        filterWidgetAction->setIcon(KIcon("view-filter"));
+        filterWidgetAction->setShortcut(Qt::CTRL + Qt::Key_F);
+        connect(filterWidgetAction, SIGNAL(triggered()), partWidget->filterBar(), SLOT(setFocus()));
+        partWidget->filterBar()->setClickMessage(i18n("Filter bibliographic entries (%1)", filterWidgetAction->shortcut().toString()));
+
+        /// Actions for creating new elements (entries, macros, ...)
+        KActionMenu *newElementAction = new KActionMenu(KIcon("address-book-new"), i18n("New element"), p);
+        p->actionCollection()->addAction("element_new", newElementAction);
+        KMenu *newElementMenu = new KMenu(newElementAction->text(), p->widget());
+        newElementAction->setMenu(newElementMenu);
+        connect(newElementAction, SIGNAL(triggered()), p, SLOT(newEntryTriggered()));
+        QAction *newEntry = newElementMenu->addAction(KIcon("address-book-new"), i18n("New entry"));
+        newEntry->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_N);
+        connect(newEntry, SIGNAL(triggered()), signalMapperNewElement, SLOT(map()));
+        signalMapperNewElement->setMapping(newEntry, smEntry);
+        QAction *newComment = newElementMenu->addAction(KIcon("address-book-new"), i18n("New comment"));
+        connect(newComment, SIGNAL(triggered()), signalMapperNewElement, SLOT(map()));
+        signalMapperNewElement->setMapping(newComment, smComment);
+        QAction *newMacro = newElementMenu->addAction(KIcon("address-book-new"), i18n("New macro"));
+        connect(newMacro, SIGNAL(triggered()), signalMapperNewElement, SLOT(map()));
+        signalMapperNewElement->setMapping(newMacro, smMacro);
+        QAction *newPreamble = newElementMenu->addAction(KIcon("address-book-new"), i18n("New preamble"));
+        connect(newPreamble, SIGNAL(triggered()), signalMapperNewElement, SLOT(map()));
+        signalMapperNewElement->setMapping(newPreamble, smPreamble);
+        connect(signalMapperNewElement, SIGNAL(mapped(int)), p, SLOT(newElementTriggered(int)));
+
+        /// Action to edit an element
+        elementEditAction = new KAction(KIcon("document-edit"), i18n("Edit Element"), p);
+        elementEditAction->setShortcut(Qt::CTRL + Qt::Key_E);
+        p->actionCollection()->addAction(QLatin1String("element_edit"), elementEditAction);
+        connect(elementEditAction, SIGNAL(triggered()), partWidget->fileView(), SLOT(editCurrentElement()));
+
+        /// Action to view the document associated to the current element
+        elementViewDocumentAction = new KAction(KIcon("application-pdf"), i18n("View Document"), p);
+        elementViewDocumentAction->setShortcut(Qt::CTRL + Qt::Key_D);
+        p->actionCollection()->addAction(QLatin1String("element_viewdocument"), elementViewDocumentAction);
+        connect(elementViewDocumentAction, SIGNAL(triggered()), p, SLOT(elementViewDocument()));
+
+        /// Action to find a PDF matching the current element
+        elementFindPDFAction = new KAction(KIcon("application-pdf"), i18n("Find PDF..."), p);
+        p->actionCollection()->addAction(QLatin1String("element_findpdf"), elementFindPDFAction);
+        connect(elementFindPDFAction, SIGNAL(triggered()), p, SLOT(elementFindPDF()));
+
+        /// Action to reformat the selected elements' ids
+        entryApplyDefaultFormatString = new KAction(KIcon("favorites"), i18n("Format entry ids"), p);
+        p->actionCollection()->addAction(QLatin1String("entry_applydefaultformatstring"), entryApplyDefaultFormatString);
+        connect(entryApplyDefaultFormatString, SIGNAL(triggered()), p, SLOT(applyDefaultFormatString()));
+
+        /// Clipboard object, required for various copy&paste operations
+        Clipboard *clipboard = new Clipboard(partWidget->fileView());
+
+        /// Actions to cut and copy selected elements as BibTeX code
+        editCutAction = p->actionCollection()->addAction(KStandardAction::Cut, clipboard, SLOT(cut()));
+        editCopyAction = p->actionCollection()->addAction(KStandardAction::Copy, clipboard, SLOT(copy()));
+
+        /// Action to copy references, e.g. '\cite{fordfulkerson1959}'
+        editCopyReferencesAction = new KAction(KIcon("edit-copy"), i18n("Copy References"), p);
+        editCopyReferencesAction->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_C);
+        p->actionCollection()->addAction(QLatin1String("edit_copy_references"), editCopyReferencesAction);
+        connect(editCopyReferencesAction, SIGNAL(triggered()), clipboard, SLOT(copyReferences()));
+
+        /// Action to paste BibTeX code
+        editPasteAction = p->actionCollection()->addAction(KStandardAction::Paste, clipboard, SLOT(paste()));
+
+        /// Action to delete selected rows/elements
+        editDeleteAction = new KAction(KIcon("edit-table-delete-row"), i18n("Delete"), p);
+        editDeleteAction->setShortcut(Qt::Key_Delete);
+        p->actionCollection()->addAction(QLatin1String("edit_delete"), editDeleteAction);
+        connect(editDeleteAction, SIGNAL(triggered()), partWidget->fileView(), SLOT(selectionDelete()));
+
+        /// Build context menu for central BibTeX file view
+        partWidget->fileView()->setContextMenuPolicy(Qt::ActionsContextMenu); ///< context menu is based on actions
+        partWidget->fileView()->addAction(elementEditAction);
+        partWidget->fileView()->addAction(elementViewDocumentAction);
+        KAction *separator = new KAction(p);
+        separator->setSeparator(true);
+        partWidget->fileView()->addAction(separator);
+        partWidget->fileView()->addAction(editCutAction);
+        partWidget->fileView()->addAction(editCopyAction);
+        partWidget->fileView()->addAction(editCopyReferencesAction);
+        partWidget->fileView()->addAction(editPasteAction);
+        partWidget->fileView()->addAction(editDeleteAction);
+        separator = new KAction(p);
+        separator->setSeparator(true);
+        partWidget->fileView()->addAction(separator);
+
+        partWidget->fileView()->addAction(elementFindPDFAction);
+        partWidget->fileView()->addAction(entryApplyDefaultFormatString);
+
+        colorLabelContextMenu = new ColorLabelContextMenu(partWidget->fileView());
+        colorLabelContextMenuAction = p->actionCollection()->addAction(QLatin1String("entry_colorlabel"), colorLabelContextMenu->menuAction());
+
+        findDuplicatesUI = new FindDuplicatesUI(p, partWidget->fileView());
+        lyx = new LyX(p, partWidget->fileView());
+
+        connect(partWidget->fileView(), SIGNAL(selectedElementsChanged()), p, SLOT(updateActions()));
+        connect(partWidget->fileView(), SIGNAL(currentElementChanged(QSharedPointer<Element>,File*)), p, SLOT(updateActions()));
+    }
+
     FileImporter *fileImporterFactory(const KUrl &url) {
         QString ending = url.path().toLower();
         int p = ending.lastIndexOf(".");
         ending = ending.mid(p + 1);
 
-        if (ending == "pdf") {
+        if (ending == QLatin1String("pdf")) {
             return new FileImporterPDF();
-        } else if (ending == "ris") {
+        } else if (ending == QLatin1String("ris")) {
             return new FileImporterRIS();
-        } else if (BibUtils::available() && ending == "isi") {
+        } else if (BibUtils::available() && ending == QLatin1String("isi")) {
             FileImporterBibUtils *fileImporterBibUtils = new FileImporterBibUtils();
             fileImporterBibUtils->setFormat(BibUtils::ISI);
             return fileImporterBibUtils;
@@ -141,30 +260,26 @@ public:
         }
     }
 
-    FileExporter *fileExporterFactory(const KUrl &url) {
-        QString ending = url.path().toLower();
-        int p = ending.lastIndexOf(".");
-        ending = ending.mid(p + 1);
-
-        if (ending == "html") {
+    FileExporter *fileExporterFactory(const QString &ending) {
+        if (ending == QLatin1String("html")) {
             return new FileExporterXSLT();
-        } else if (ending == "xml") {
+        } else if (ending == QLatin1String("xml")) {
             return new FileExporterXML();
-        } else if (ending == "ris") {
+        } else if (ending == QLatin1String("ris")) {
             return new FileExporterRIS();
-        } else if (ending == "pdf") {
+        } else if (ending == QLatin1String("pdf")) {
             return new FileExporterPDF();
-        } else if (ending == "ps") {
+        } else if (ending == QLatin1String("ps")) {
             return new FileExporterPS();
-        } else if (BibUtils::available() && ending == "isi") {
+        } else if (BibUtils::available() && ending == QLatin1String("isi")) {
             FileExporterBibUtils *fileExporterBibUtils = new FileExporterBibUtils();
             fileExporterBibUtils->setFormat(BibUtils::ISI);
             return fileExporterBibUtils;
-        } else if (ending == "rtf") {
+        } else if (ending == QLatin1String("rtf")) {
             return new FileExporterRTF();
-        } else if (ending == "html" || ending == "htm") {
+        } else if (ending == QLatin1String("html") || ending == QLatin1String("htm")) {
             return new FileExporterBibTeX2HTML();
-        } else if (ending == "bbl") {
+        } else if (ending == QLatin1String("bbl")) {
             return new FileExporterBibTeXOutput(FileExporterBibTeXOutput::BibTeXBlockList);
         } else {
             return new FileExporterBibTeX();
@@ -269,10 +384,10 @@ public:
         /// copy e.g. test.bib~ to test.bib~2 and test.bib~3 to test.bib~4 etc.
         for (int i = numberOfBackups - 1; copySucceeded && i >= 1; --i) {
             KUrl a(url);
-            a.setFileName(url.fileName() + (i > 1 ? QString("~%1").arg(i) : QLatin1String("~")));
+            a.setFileName(url.fileName() + (i > 1 ? QString(QLatin1String("~%1")).arg(i) : QLatin1String("~")));
             if (KIO::NetAccess::exists(a, KIO::NetAccess::DestinationSide, p->widget())) {
                 KUrl b(url);
-                b.setFileName(url.fileName() + QString("~%1").arg(i + 1));
+                b.setFileName(url.fileName() + QString(QLatin1String("~%1")).arg(i + 1));
                 KIO::NetAccess::del(b, p->widget());
                 copySucceeded = KIO::NetAccess::file_copy(a, b, p->widget());
             }
@@ -318,22 +433,8 @@ public:
         return selectedUrl;
     }
 
-    bool saveFile(const KUrl &url) {
-        Q_ASSERT_X(!url.isEmpty(), "bool KBibTeXPart::KBibTeXPartPrivate:saveFile(const KUrl &url)", "url is not allowed to be empty");
-
-        /// configure and open temporary file
-        KTemporaryFile temporaryFile;
-        const QRegExp suffixRegExp("\\.[^.]{1,4}$");
-        if (suffixRegExp.indexIn(url.pathOrUrl()) >= 0)
-            temporaryFile.setSuffix(suffixRegExp.cap(0));
-        temporaryFile.setAutoRemove(true);
-        if (!temporaryFile.open())
-            return false;
-
-        /// export bibliography data into temporary file
-        SortFilterFileModel *model = qobject_cast<SortFilterFileModel *>(partWidget->fileView()->model());
-        Q_ASSERT_X(model != NULL, "bool KBibTeXPart::KBibTeXPartPrivate:saveFile(const KUrl &url)", "SortFilterFileModel *model from editor->model() is invalid");
-        FileExporter *exporter = fileExporterFactory(url);
+    FileExporter *saveFileExporter(const QString &ending) {
+        FileExporter *exporter = fileExporterFactory(ending);
 
         if (isSaveAsOperation) {
             /// only show export dialog at SaveAs or SaveCopyAs operations
@@ -370,41 +471,88 @@ public:
             }
         }
 
+        return exporter;
+    }
+
+    bool saveFile(QFile &file, FileExporter *exporter, QStringList *errorLog = NULL) {
+        SortFilterFileModel *model = qobject_cast<SortFilterFileModel *>(partWidget->fileView()->model());
+        Q_ASSERT_X(model != NULL, "FileExporter *KBibTeXPart::KBibTeXPartPrivate:saveFile(...)", "SortFilterFileModel *model from editor->model() is invalid");
+
+        return exporter->save(&file, model->fileSourceModel()->bibliographyFile(), errorLog);
+    }
+
+    bool saveFile(const KUrl &url) {
+        bool result = false;
+        Q_ASSERT_X(!url.isEmpty(), "bool KBibTeXPart::KBibTeXPartPrivate:saveFile(const KUrl &url))", "url is not allowed to be empty");
+
+        /// Extract filename extension (e.g. 'bib') to determine which FileExporter to use
+        static const QRegExp suffixRegExp("\\.([^.]{1,4})$");
+        const QString ending = suffixRegExp.indexIn(url.pathOrUrl().toLower()) > 0 ? suffixRegExp.cap(1) : QLatin1String("bib");
+        FileExporter *exporter = saveFileExporter(ending);
+
+        /// String list to collect error message from FileExporer
+        QStringList errorLog;
+
         qApp->setOverrideCursor(Qt::WaitCursor);
 
-        QStringList errorLog;
-        bool result = exporter->save(&temporaryFile, model->fileSourceModel()->bibliographyFile(), &errorLog);
-
-        if (!result) {
-            delete exporter;
-            qApp->restoreOverrideCursor();
-            KMessageBox::errorList(p->widget(), i18n("Saving the bibliography to file '%1' failed.\n\nThe following output was generated by the export filter:", url.pathOrUrl()), errorLog, i18n("Saving bibliography failed"));
-            return false;
-        }
-
-        /// close/flush temporary file
-        temporaryFile.close();
-        /// make backup before overwriting target destination
-        makeBackup(url);
-        /// upload temporary file to target destination
-        KUrl realUrl = url;
         if (url.isLocalFile()) {
-            /// take precautions for local files
-            QFileInfo fileInfo(url.pathOrUrl());
-            if (fileInfo.isSymLink()) {
-                /// do not overwrite symbolic link,
-                /// but linked file instead
-                realUrl = KUrl::fromLocalFile(fileInfo.symLinkTarget());
+            /// Take precautions for local files
+            QFileInfo fileInfo(url.path());
+            /// Do not overwrite symbolic link, but linked file instead
+            QString filename = fileInfo.absoluteFilePath();
+            while (fileInfo.isSymLink()) {
+                filename = fileInfo.symLinkTarget();
+                fileInfo = QFileInfo(filename);
+            }
+
+            if (!fileInfo.exists() || fileInfo.isWritable()) {
+                /// Make backup before overwriting target destination, intentionally
+                /// using the provided filename, not the resolved symlink
+                makeBackup(url);
+
+                QFile file(filename);
+                if (file.open(QIODevice::WriteOnly)) {
+                    result = saveFile(file, exporter, &errorLog);
+                    file.close();
+                }
+            }
+        } else {
+            /// URL points to a remote location
+
+            /// Configure and open temporary file
+            KTemporaryFile temporaryFile;
+            temporaryFile.setSuffix(QLatin1String(".") + ending);
+            temporaryFile.setAutoRemove(true);
+            if (temporaryFile.open()) {
+                result = saveFile(temporaryFile, exporter, &errorLog);
+
+                /// Close/flush temporary file
+                temporaryFile.close();
+
+                if (result) {
+                    /// Make backup before overwriting target destination
+                    makeBackup(url);
+
+                    KIO::NetAccess::del(url, p->widget()); ///< delete target first before copying to its location
+                    result = KIO::NetAccess::file_copy(temporaryFile.fileName(), url, p->widget());
+                }
             }
         }
-        KIO::NetAccess::del(realUrl, p->widget());
-        result &= KIO::NetAccess::file_copy(temporaryFile.fileName(), realUrl, p->widget());
 
         qApp->restoreOverrideCursor();
-        if (!result)
-            KMessageBox::error(p->widget(), i18n("Saving the bibliography to file '%1' failed.", url.pathOrUrl()), i18n("Saving bibliography failed"));
 
         delete exporter;
+
+        if (!result) {
+            QString msg = i18n("Saving the bibliography to file '%1' failed.", url.pathOrUrl());
+            if (errorLog.isEmpty())
+                KMessageBox::error(p->widget(), msg, i18n("Saving bibliography failed"));
+            else {
+                msg += QLatin1String("\n\n");
+                msg += i18n("The following output was generated by the export filter:");
+                KMessageBox::errorList(p->widget(), msg, errorLog, i18n("Saving bibliography failed"));
+            }
+        }
         return result;
     }
 
@@ -434,7 +582,7 @@ public:
 
                     // FIXME: the signal mapper will fill up with mappings, as they are never removed
                     QFileInfo fi((*it).pathOrUrl());
-                    const QString label = QString("%1 [%2]").arg(fi.fileName()).arg(fi.absolutePath());
+                    const QString label = QString(QLatin1String("%1 [%2]")).arg(fi.fileName(), fi.absolutePath());
                     KAction *action = new KAction(KIcon(KMimeType::iconNameForUrl(*it)), label, p);
                     action->setData((*it).pathOrUrl());
                     action->setToolTip((*it).prettyUrl());
@@ -488,17 +636,15 @@ public:
 };
 
 KBibTeXPart::KBibTeXPart(QWidget *parentWidget, QObject *parent, bool browserViewWanted)
-        : KParts::ReadWritePart(parent), d(new KBibTeXPartPrivate(this))
+        : KParts::ReadWritePart(parent), d(new KBibTeXPartPrivate(parentWidget, this))
 {
+    Q_UNUSED(browserViewWanted)
+
     setComponentData(KBibTeXPartFactory::componentData());
     setObjectName("KBibTeXPart::KBibTeXPart");
 
-    d->partWidget = new PartWidget(parentWidget);
-    d->partWidget->fileView()->setReadOnly(!isReadWrite());
-    connect(d->partWidget->fileView(), SIGNAL(modified()), this, SLOT(setModified()));
     setWidget(d->partWidget);
-
-    setupActions(browserViewWanted);
+    updateActions();
 
     /* // FIXME
     if (browserViewWanted)
@@ -507,6 +653,8 @@ KBibTeXPart::KBibTeXPart(QWidget *parentWidget, QObject *parent, bool browserVie
 
     d->initializeNew();
 
+    setXMLFile(RCFileName);
+
     NotificationHub::registerNotificationListener(this, NotificationHub::EventConfigurationChanged);
     d->readConfiguration();
 
@@ -532,111 +680,6 @@ void KBibTeXPart::notificationEvent(int eventId)
         d->readConfiguration();
 }
 
-void KBibTeXPart::setupActions(bool /*browserViewWanted FIXME*/)
-{
-    d->fileSaveAction = actionCollection()->addAction(KStandardAction::Save, this, SLOT(documentSave()));
-    d->fileSaveAction->setEnabled(false);
-    actionCollection()->addAction(KStandardAction::SaveAs, this, SLOT(documentSaveAs()));
-    KAction *saveCopyAsAction = new KAction(KIcon("document-save"), i18n("Save Copy As..."), this);
-    actionCollection()->addAction("file_save_copy_as", saveCopyAsAction);
-    connect(saveCopyAsAction, SIGNAL(triggered()), this, SLOT(documentSaveCopyAs()));
-
-    KAction *filterWidgetAction = new KAction(i18n("Filter"), this);
-    actionCollection()->addAction("toolbar_filter_widget", filterWidgetAction);
-    filterWidgetAction->setIcon(KIcon("view-filter"));
-    filterWidgetAction->setShortcut(Qt::CTRL + Qt::Key_F);
-    connect(filterWidgetAction, SIGNAL(triggered()), d->partWidget->filterBar(), SLOT(setFocus()));
-    d->partWidget->filterBar()->setClickMessage(i18n("Filter bibliographic entries (%1)", filterWidgetAction->shortcut().toString()));
-
-    KActionMenu *newElementAction = new KActionMenu(KIcon("address-book-new"), i18n("New element"), this);
-    actionCollection()->addAction("element_new", newElementAction);
-    KMenu *newElementMenu = new KMenu(newElementAction->text(), widget());
-    newElementAction->setMenu(newElementMenu);
-    connect(newElementAction, SIGNAL(triggered()), this, SLOT(newEntryTriggered()));
-    QAction *newEntry = newElementMenu->addAction(KIcon("address-book-new"), i18n("New entry"));
-    newEntry->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_N);
-    connect(newEntry, SIGNAL(triggered()), d->signalMapperNewElement, SLOT(map()));
-    d->signalMapperNewElement->setMapping(newEntry, smEntry);
-    QAction *newComment = newElementMenu->addAction(KIcon("address-book-new"), i18n("New comment"));
-    connect(newComment, SIGNAL(triggered()), d->signalMapperNewElement, SLOT(map()));
-    d->signalMapperNewElement->setMapping(newComment, smComment);
-    QAction *newMacro = newElementMenu->addAction(KIcon("address-book-new"), i18n("New macro"));
-    connect(newMacro, SIGNAL(triggered()), d->signalMapperNewElement, SLOT(map()));
-    d->signalMapperNewElement->setMapping(newMacro, smMacro);
-    QAction *newPreamble = newElementMenu->addAction(KIcon("address-book-new"), i18n("New preamble"));
-    connect(newPreamble, SIGNAL(triggered()), d->signalMapperNewElement, SLOT(map()));
-    d->signalMapperNewElement->setMapping(newPreamble, smPreamble);
-    connect(d->signalMapperNewElement, SIGNAL(mapped(int)), this, SLOT(newElementTriggered(int)));
-    d->elementEditAction = new KAction(KIcon("document-edit"), i18n("Edit Element"), this);
-    d->elementEditAction->setShortcut(Qt::CTRL + Qt::Key_E);
-    actionCollection()->addAction(QLatin1String("element_edit"),  d->elementEditAction);
-    connect(d->elementEditAction, SIGNAL(triggered()), d->partWidget->fileView(), SLOT(editCurrentElement()));
-    d->elementViewDocumentAction = new KAction(KIcon("application-pdf"), i18n("View Document"), this);
-    d->elementViewDocumentAction->setShortcut(Qt::CTRL + Qt::Key_D);
-    actionCollection()->addAction(QLatin1String("element_viewdocument"),  d->elementViewDocumentAction);
-    connect(d->elementViewDocumentAction, SIGNAL(triggered()), this, SLOT(elementViewDocument()));
-
-    d->elementFindPDFAction = new KAction(KIcon("application-pdf"), i18n("Find PDF..."), this);
-    actionCollection()->addAction(QLatin1String("element_findpdf"),  d->elementFindPDFAction);
-    connect(d->elementFindPDFAction, SIGNAL(triggered()), this, SLOT(elementFindPDF()));
-
-    d->entryApplyDefaultFormatString = new KAction(KIcon("favorites"), i18n("Format entry ids"), this);
-    actionCollection()->addAction(QLatin1String("entry_applydefaultformatstring"), d->entryApplyDefaultFormatString);
-    connect(d->entryApplyDefaultFormatString, SIGNAL(triggered()), this, SLOT(applyDefaultFormatString()));
-
-    Clipboard *clipboard = new Clipboard(d->partWidget->fileView());
-
-    d->editCopyReferencesAction = new KAction(KIcon("edit-copy"), i18n("Copy References"), this);
-    d->editCopyReferencesAction->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_C);
-    actionCollection()->addAction(QLatin1String("edit_copy_references"),  d->editCopyReferencesAction);
-    connect(d->editCopyReferencesAction, SIGNAL(triggered()), clipboard, SLOT(copyReferences()));
-
-    d->editDeleteAction = new KAction(KIcon("edit-table-delete-row"), i18n("Delete"), this);
-    d->editDeleteAction->setShortcut(Qt::Key_Delete);
-    actionCollection()->addAction(QLatin1String("edit_delete"),  d->editDeleteAction);
-    connect(d->editDeleteAction, SIGNAL(triggered()), d->partWidget->fileView(), SLOT(selectionDelete()));
-
-    d->editCutAction = actionCollection()->addAction(KStandardAction::Cut, clipboard, SLOT(cut()));
-    d->editCopyAction = actionCollection()->addAction(KStandardAction::Copy, clipboard, SLOT(copy()));
-    actionCollection()->addAction(QLatin1String("edit_copy_references"),  d->editCopyReferencesAction);
-    d->editPasteAction = actionCollection()->addAction(KStandardAction::Paste, clipboard, SLOT(paste()));
-
-    /// build context menu for central BibTeX file view
-    d->partWidget->fileView()->setContextMenuPolicy(Qt::ActionsContextMenu);
-    d->partWidget->fileView()->addAction(d->elementEditAction);
-    d->partWidget->fileView()->addAction(d->elementViewDocumentAction);
-    QAction *separator = new QAction(this);
-    separator->setSeparator(true);
-    d->partWidget->fileView()->addAction(separator);
-    d->partWidget->fileView()->addAction(d->editCutAction);
-    d->partWidget->fileView()->addAction(d->editCopyAction);
-    d->partWidget->fileView()->addAction(d->editCopyReferencesAction);
-    d->partWidget->fileView()->addAction(d->editPasteAction);
-    d->partWidget->fileView()->addAction(d->editDeleteAction);
-    separator = new QAction(this);
-    separator->setSeparator(true);
-    d->partWidget->fileView()->addAction(separator);
-
-    // TODO
-
-    connect(d->partWidget->fileView(), SIGNAL(selectedElementsChanged()), this, SLOT(updateActions()));
-    connect(d->partWidget->fileView(), SIGNAL(currentElementChanged(QSharedPointer<Element>,File*)), this, SLOT(updateActions()));
-
-    d->partWidget->fileView()->addAction(d->elementFindPDFAction);
-    d->partWidget->fileView()->addAction(d->entryApplyDefaultFormatString);
-
-    d->colorLabelContextMenu = new ColorLabelContextMenu(d->partWidget->fileView());
-    d->colorLabelContextMenuAction = actionCollection()->addAction(QLatin1String("entry_colorlabel"), d->colorLabelContextMenu->menuAction());
-
-    setXMLFile(RCFileName);
-
-    d->findDuplicatesUI = new FindDuplicatesUI(this, d->partWidget->fileView());
-    d->lyx = new LyX(this, d->partWidget->fileView());
-
-    updateActions();
-    fitActionSettings();
-}
-
 bool KBibTeXPart::saveFile()
 {
     Q_ASSERT_X(isReadWrite(), "bool KBibTeXPart::saveFile()", "Trying to save although document is in read-only mode");
@@ -654,7 +697,7 @@ bool KBibTeXPart::saveFile()
     if (!watchableFilename.isEmpty())
         d->fileSystemWatcher.removePath(watchableFilename);
 
-    const bool saveOperationSuccess = d->saveFile(localFilePath());
+    const bool saveOperationSuccess = d->saveFile(url());
 
     /// Continue watching local file after write operation
     if (!watchableFilename.isEmpty())
@@ -692,7 +735,8 @@ bool KBibTeXPart::documentSaveAs()
 
     if (KParts::ReadWritePart::saveAs(newUrl)) {
         kDebug() << "setting url to be " << newUrl.pathOrUrl();
-        d->model->bibliographyFile()->setProperty(File::Url, newUrl);
+        Q_ASSERT_X(d->model->bibliographyFile() == d->bibTeXFile, "bool KBibTeXPart::documentSaveAs()", "d->model->bibliographyFile() != d->bibTeXFile");
+        d->bibTeXFile->setProperty(File::Url, newUrl);
         return true;
     } else
         return false;
@@ -744,7 +788,7 @@ void KBibTeXPart::elementViewDocument()
 
 void KBibTeXPart::elementViewDocumentMenu(QObject *obj)
 {
-    QString text = static_cast<QAction *>(obj)->data().toString(); ///< only a KAction will be passed along
+    QString text = static_cast<QAction *>(obj)->data().toString(); ///< only a QAction will be passed along
 
     /// Guess mime type for url to open
     KUrl url(text);
@@ -781,11 +825,6 @@ void KBibTeXPart::applyDefaultFormatString()
 
 }
 
-void KBibTeXPart::fitActionSettings()
-{
-    // TODO
-}
-
 bool KBibTeXPart::openFile()
 {
     const bool success = d->openFile(url(), localFilePath());
@@ -885,7 +924,7 @@ void KBibTeXPart::updateActions()
     d->elementViewDocumentAction->setEnabled(!emptySelection && numDocumentsToView > 0);
     /// activate sub-menu only if there are at least two documents to view
     d->elementViewDocumentAction->setMenu(numDocumentsToView > 1 ? d->viewDocumentMenu : NULL);
-    d->elementViewDocumentAction->setToolTip(numDocumentsToView == 1 ? d->viewDocumentMenu->actions().first()->text() : QLatin1String(""));
+    d->elementViewDocumentAction->setToolTip(numDocumentsToView == 1 ? (*d->viewDocumentMenu->actions().constBegin())->text() : QLatin1String(""));
 
     /// update list of references which can be sent to LyX
     QStringList references;
