@@ -142,7 +142,7 @@ public:
     }
 
     DocumentPreviewPrivate(DocumentPreview *parent)
-            : p(parent), config(KSharedConfig::openConfig(QLatin1String("kbibtexrc"))), entry(NULL) {
+            : p(parent), config(KSharedConfig::openConfig(QLatin1String("kbibtexrc"))), anyLocal(false), entry(NULL), anyRemote(false) {
         setupGUI();
     }
 
@@ -239,7 +239,7 @@ public:
             QString fn = urlInfo.url.fileName();
             QString full = urlInfo.url.pathOrUrl();
             QString dir = urlInfo.url.directory();
-            QString text = fn.isEmpty() ? full : (dir.isEmpty() ? fn : QString("%1 [%2]").arg(fn).arg(dir));
+            QString text = fn.isEmpty() ? full : (dir.isEmpty() ? fn : QString(QLatin1String("%1 [%2]")).arg(fn, dir));
             urlComboBox->addItem(urlInfo.icon, text);
         } else {
             /// create a drop-down list entry if file is a remote file
