@@ -67,7 +67,6 @@
 #include "onlinesearchisbndb.h"
 #include "onlinesearchideasrepec.h"
 #include "onlinesearchdoi.h"
-#include "onlinesearchoclcworldcat.h"
 #include "openfileinfo.h"
 #include "fileview.h"
 #include "filemodel.h"
@@ -106,7 +105,7 @@ public:
     SearchFormPrivate(SearchResults *searchResults, SearchForm *parent)
             : p(parent), whichEnginesLabel(NULL), config(KSharedConfig::openConfig(QLatin1String("kbibtexrc"))),
           configGroupName(QLatin1String("Search Engines Docklet")), sr(searchResults), searchButton(NULL), useEntryButton(NULL), currentEntry(NULL) {
-        // nothing
+        createGUI();
     }
 
     OnlineSearchQueryFormAbstract *currentQueryForm() {
@@ -185,7 +184,6 @@ public:
         tabWidget = new KTabWidget(p);
         tabWidget->setDocumentMode(true);
         layout->addWidget(tabWidget, 0, 0, 1, 3);
-        connect(tabWidget, SIGNAL(currentChanged(int)), p, SLOT(tabSwitched(int)));
 
         QWidget *widget = createQueryTermsStack(tabWidget);
         tabWidget->addTab(widget, KIcon("edit-rename"), i18n("Query Terms"));
@@ -193,6 +191,8 @@ public:
         QWidget *listContainer = createEnginesGUI(tabWidget);
         tabWidget->addTab(listContainer, KIcon("applications-engineering"), i18n("Engines"));
 
+        connect(tabWidget, SIGNAL(currentChanged(int)), p, SLOT(tabSwitched(int)));
+
         useEntryButton = new KPushButton(KIcon("go-up"), i18n("Use Entry"), p);
         layout->addWidget(useEntryButton, 1, 0, 1, 1);
         useEntryButton->setEnabled(false);
@@ -207,7 +207,6 @@ public:
         layout->addWidget(searchButton, 1, 2, 1, 1);
         connect(generalQueryTermsForm, SIGNAL(returnPressed()), searchButton, SLOT(click()));
 
-        loadEngines();
         updateGUI();
     }
 
@@ -232,7 +231,6 @@ public:
         addEngine(new OnlineSearchIsbnDB(p));
         addEngine(new OnlineSearchIDEASRePEc(p));
         addEngine(new OnlineSearchDOI(p));
-        // TODO needs a valid WSKey // addEngine(new OnlineSearchOCLCWorldCat(p));
 
         p->itemCheckChanged(NULL);
         updateGUI();
@@ -342,7 +340,7 @@ public:
 SearchForm::SearchForm(SearchResults *searchResults, QWidget *parent)
         : QWidget(parent), d(new SearchFormPrivate(searchResults, this))
 {
-    d->createGUI();
+    d->loadEngines();
     d->switchToSearch();
 }
 
