@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -21,7 +21,7 @@
 #include <QDragEnterEvent>
 #include <QDropEvent>
 #include <QLabel>
-#include <QtCore/QPointer>
+#include <QPointer>
 #include <QTimer>
 
 #include <KIO/NetAccess>
@@ -97,8 +97,8 @@ public:
     }
 };
 
-KBibTeXMainWindow::KBibTeXMainWindow()
-        : KParts::MainWindow(), d(new KBibTeXMainWindowPrivate(this))
+KBibTeXMainWindow::KBibTeXMainWindow(QWidget *parent)
+        : KParts::MainWindow(parent, (Qt::WindowFlags)KDE_DEFAULT_WINDOWFLAGS), d(new KBibTeXMainWindowPrivate(this))
 {
     setObjectName(QLatin1String("KBibTeXShell"));
 
@@ -158,7 +158,7 @@ KBibTeXMainWindow::KBibTeXMainWindow()
     d->dockStatistics = new QDockWidget(i18n("Statistics"), this);
     d->dockStatistics->setAllowedAreas(Qt::BottomDockWidgetArea | Qt::TopDockWidgetArea | Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
     addDockWidget(Qt::LeftDockWidgetArea, d->dockStatistics);
-    d->statistics = new Statistics(d->dockStatistics);
+    d->statistics = new Statistics(d->mdiWidget->getOpenFileInfoManager(), d->dockStatistics);
     d->dockStatistics->setWidget(d->statistics);
     d->dockStatistics->setObjectName("dockStatistics");
     d->dockStatistics->setFeatures(QDockWidget::DockWidgetClosable | QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
@@ -189,6 +189,7 @@ KBibTeXMainWindow::KBibTeXMainWindow()
     d->dockZotero->setAllowedAreas(Qt::BottomDockWidgetArea | Qt::TopDockWidgetArea | Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
     addDockWidget(Qt::LeftDockWidgetArea, d->dockZotero);
     d->zotero = new ZoteroBrowser(d->searchResults, d->dockZotero);
+    connect(d->zotero, SIGNAL(itemToShow()), this, SLOT(showSearchResults()));
     d->dockZotero->setWidget(d->zotero);
     d->dockZotero->setObjectName("dockZotero");
     d->dockZotero->setFeatures(QDockWidget::DockWidgetClosable | QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
@@ -227,7 +228,7 @@ KBibTeXMainWindow::KBibTeXMainWindow()
     d->dockFileSettings = new QDockWidget(i18n("File Settings"), this);
     d->dockFileSettings->setAllowedAreas(Qt::BottomDockWidgetArea | Qt::TopDockWidgetArea | Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
     addDockWidget(Qt::LeftDockWidgetArea, d->dockFileSettings);
-    d->fileSettings = new FileSettings(d->dockFileSettings);
+    d->fileSettings = new FileSettings(d->mdiWidget->getOpenFileInfoManager(), d->dockFileSettings);
     d->dockFileSettings->setWidget(d->fileSettings);
     d->dockFileSettings->setObjectName("dockFileSettings");
     d->dockFileSettings->setFeatures(QDockWidget::DockWidgetClosable | QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
@@ -401,10 +402,7 @@ void KBibTeXMainWindow::documentSwitched(FileView *oldFileView, FileView *newFil
     d->documentPreview->setElement(QSharedPointer<Element>(), NULL);
     d->valueList->setFileView(newFileView);
     d->fileSettings->setFileView(newFileView);
-    if (newFileView != NULL && newFileView->fileModel() != NULL)
-        d->statistics->setFile(newFileView->fileModel()->bibliographyFile(), newFileView->selectionModel());
-    else
-        d->statistics->setFile(NULL, NULL);
+    d->statistics->setFileView(newFileView);
     d->referencePreview->setFileView(newFileView);
 }
 
@@ -424,7 +422,7 @@ void KBibTeXMainWindow::documentListsChanged(OpenFileInfo::StatusFlags statusFla
             const int squeezeLen = 64;
             const QString squeezedShortCap = squeeze_text(cur->shortCaption(), squeezeLen);
             const QString squeezedFullCap = squeeze_text(cur->fullCaption(), squeezeLen);
-            KAction *action = new KAction(QString("%1 [%2]").arg(squeezedShortCap).arg(squeezedFullCap), this);
+            KAction *action = new KAction(QString(QLatin1String("%1 [%2]")).arg(squeezedShortCap, squeezedFullCap), this);
             action->setData(cur->url());
             action->setIcon(KIcon(cur->mimeType().replace(QLatin1Char('/'), QLatin1Char('-'))));
             d->actionMenuRecentFilesMenu->addAction(action);
