@@ -1,40 +1,37 @@
 /***************************************************************************
-*   Copyright (C) 2004-2012 by Thomas Fischer                             *
-*   fischer@unix-ag.uni-kl.de                                             *
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-*   This program is distributed in the hope that it will be useful,       *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
-*   GNU General Public License for more details.                          *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the                         *
-*   Free Software Foundation, Inc.,                                       *
-*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
-***************************************************************************/
+ *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ ***************************************************************************/
 
 #include <KCmdLineArgs>
 #include <KApplication>
 #include <KAboutData>
 #include <KMessageBox>
+#include <KDebug>
 
-#include "program.h"
 #include "mainwindow.h"
-const char *versionNumber = "0.5";
+#include "version.h"
 
 const char *description = I18N_NOOP("A BibTeX editor for KDE");
-const char *programHomepage = I18N_NOOP("http://home.gna.org/kbibtex/");
+const char *programHomepage = "http://home.gna.org/kbibtex/";
 
 int main(int argc, char *argv[])
 {
     KAboutData aboutData("kbibtex", 0, ki18n("KBibTeX"), versionNumber,
                          ki18n(description), KAboutData::License_GPL_V2,
-                         ki18n("Copyright 2004-2013 Thomas Fischer"), KLocalizedString(),
+                         ki18n("Copyright 2004-2014 Thomas Fischer"), KLocalizedString(),
                          programHomepage);
     aboutData.addAuthor(ki18n("Thomas Fischer"), ki18n("Maintainer"), "fischer@unix-ag.uni-kl.de", "http://www.t-fischer.net/");
 
@@ -45,6 +42,8 @@ int main(int argc, char *argv[])
     KCmdLineArgs::init(argc, argv, &aboutData);
     KApplication programCore;
 
+    kDebug() << "Starting KBibTeX version" << versionNumber;
+
     KService::Ptr service = KService::serviceByStorageId("kbibtexpart.desktop");
     if (service.isNull())
         KMessageBox::error(NULL, i18n("KBibTeX seems to be not installed completely. KBibTeX could not locate its own KPart.\n\nOnly limited functionality will be available."), i18n("Incomplete KBibTeX Installation"));
@@ -59,7 +58,7 @@ int main(int argc, char *argv[])
         KCmdLineArgs *arguments = KCmdLineArgs::parsedArgs();
 
         for (int i = 0; i < arguments->count(); ++i) {
-            KUrl url(arguments->arg(i));
+            const KUrl url = arguments->url(i);
             if (url.isValid())
                 mainWindow->openDocument(url);
         }
